@@ -20,7 +20,7 @@
 
 /**
  * SECTION:asc-compose
- * @short_description: Compose collection metadata easily.
+ * @short_description: Compose catalog metadata easily.
  * @include: appstream-compose.h
  */
 
@@ -295,7 +295,7 @@ asc_compose_get_format (AscCompose *compose)
  * @compose: an #AscCompose instance.
  * @kind: The format, e.g. %AS_FORMAT_KIND_XML
  *
- * Set the format kind of the collection metadata that we should generate.
+ * Set the format kind of the catalog metadata that we should generate.
  */
 void
 asc_compose_set_format (AscCompose *compose, AsFormatKind kind)
@@ -1409,6 +1409,7 @@ asc_compose_process_task_cb (AscComposeTask *ctask, AscCompose *compose)
 	/* process metadata */
 	for (guint i = 0; i < mi_fnames->len; i++) {
 		g_autoptr(GBytes) mi_bytes = NULL;
+		g_autoptr(GBytes) rel_bytes = NULL;
 		g_autoptr(GError) local_error = NULL;
 		g_autoptr(AsComponent) cpt = NULL;
 		g_autofree gchar *mi_basename = NULL;
@@ -1455,13 +1456,23 @@ asc_compose_process_task_cb (AscComposeTask *ctask, AscCompose *compose)
 					  g_strdup (as_component_get_id (cpt)));
 		}
 
+		/* process any release information of this component and download release data if needed */
+		asc_process_metainfo_releases (ctask->result,
+					       ctask->unit,
+					       cpt,
+					       mi_fname,
+					       as_flags_contains (priv->flags, ASC_COMPOSE_FLAG_ALLOW_NET),
+					       acurl,
+					       &rel_bytes);
+
 		/* validate the data */
 		if (as_flags_contains (priv->flags, ASC_COMPOSE_FLAG_VALIDATE)) {
 			asc_validate_metainfo_data_for_component (ctask->result,
-									validator,
-									cpt,
-									mi_bytes,
-									mi_basename);
+								  validator,
+								  cpt,
+								  mi_bytes,
+								  mi_basename,
+								  rel_bytes);
 		}
 
 		/* legacy support: Synthesize launchable entry if none was set,
@@ -1964,7 +1975,7 @@ asc_compose_save_metadata_result (AscCompose *compose, gboolean *results_not_emp
 	g_autofree gchar *data_fname = NULL;
 
 	mdata = as_metadata_new ();
-	as_metadata_set_format_style (mdata, AS_FORMAT_STYLE_COLLECTION);
+	as_metadata_set_format_style (mdata, AS_FORMAT_STYLE_CATALOG);
 	as_metadata_set_format_version (mdata, AS_FORMAT_VERSION_CURRENT);
 
 	/* Set baseurl only if one is set and we actually store any screenshot media. If no screenshot media
@@ -2003,7 +2014,7 @@ asc_compose_save_metadata_result (AscCompose *compose, gboolean *results_not_emp
 	}
 
 	data_fname = g_build_filename (priv->data_result_dir, data_basename, NULL);
-	return as_metadata_save_collection (mdata, data_fname, priv->format, error);
+	return as_metadata_save_catalog (mdata, data_fname, priv->format, error);
 }
 
 /**
@@ -2045,7 +2056,7 @@ asc_compose_finalize_result (AscCompose *compose, AscResult *result)
  * @cancellable: a #GCancellable.
  * @error: A #GError or %NULL.
  *
- * Process the registered units and generate collection metadata from
+ * Process the registered units and generate catalog metadata from
  * found components.
  *
  * Returns: (transfer none) (element-type AscResult): The results, or %NULL on error
