@@ -50,6 +50,11 @@ AscHintTagStatic asc_hint_tag_list[] =  {
 	  "Dummy info hint for the testsuite. Var1: {{var1}}."
 	},
 
+	{ "unit-read-error",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  "Error while reading data from unit <code>{{name}}</code>: {{msg}}",
+	},
+
 	{ "ancient-metadata",
 	  AS_ISSUE_SEVERITY_WARNING,
 	  "The AppStream metadata should be updated to follow a more recent version of the specification.<br/>"
@@ -98,6 +103,16 @@ AscHintTagStatic asc_hint_tag_list[] =  {
 	  "<code>type=</code> property of the component root-node in the MetaInfo XML file does not contain a spelling mistake."
 	},
 
+	{ "metainfo-releases-download-failed",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  "Unable to download release information from <code>{{url}}</code>. The error message was: {{msg}}."
+	},
+
+	{ "metainfo-releases-read-failed",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  "Unable to read release information from <code>{{path}}</code>. The error message was: {{msg}}."
+	},
+
 	{ "file-read-error",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  "Unable to read data from file <code>{{fname}}</code>: {{msg}}",
@@ -108,36 +123,16 @@ AscHintTagStatic asc_hint_tag_list[] =  {
 	  "Unable to read data from .desktop file: {{msg}}",
 	},
 
-	{ "desktop-entry-bad-data",
+	{ "desktop-entry-hidden-set",
 	  AS_ISSUE_SEVERITY_WARNING,
-	  "Error while reading some data from the desktop-entry file: {{hint}}",
-	},
-
-	{ "desktop-entry-category-invalid",
-	  AS_ISSUE_SEVERITY_WARNING,
-	  "The category name {{hint}} is invalid. The software can not be shown in this category.",
-	},
-
-	{ "desktop-entry-value-invalid-chars",
-	  AS_ISSUE_SEVERITY_WARNING,
-	  "The desktop-entry field value for {{hint}} contains invalid or non-printable UTF-8 characters, which can not be properly displayed.",
-	},
-
-	{ "desktop-file-hidden-set",
-	  AS_ISSUE_SEVERITY_WARNING,
-	  "This .desktop file has the 'Hidden' property set. This is wrong for vendor-installed .desktop files, and "
+	  "The desktop-entry file `{{location}}` has the 'Hidden' property set. This is wrong for vendor-installed .desktop files, and "
 	  "nullifies all effects this .desktop file has (including MIME associations), which most certainly is not intentional. "
 	  "See <a href=\"https://standards.freedesktop.org/desktop-entry-spec/latest/ar01s06.html\">the specification</a> for details."
 	},
 
-	{ "desktop-entry-value-quoted",
-	  AS_ISSUE_SEVERITY_WARNING,
-	  "The desktop entry field value {{hint}} is quoted, which is likely unintentional."
-	},
-
 	{ "desktop-entry-empty-onlyshowin",
 	  AS_ISSUE_SEVERITY_WARNING,
-	  "This .desktop file has the 'OnlyShowIn' property set with an empty value. This might not be intended, as this will hide "
+	  "The desktop-entry file `{{location}}` has the 'OnlyShowIn' property set with an empty value. This might not be intended, as this will hide "
 	  "the application from all desktops. If you do want to hide the application from all desktops, using 'NoDisplay=true' is more explicit. "
 	  "See <a href=\"https://standards.freedesktop.org/desktop-entry-spec/latest/ar01s06.html\">the specification</a> for details."
 	},
@@ -304,6 +299,12 @@ AscHintTagStatic asc_hint_tag_list[] =  {
 	  "on how to write a MetaInfo file, or file a bug with the upstream author of this software component."
 	},
 
+	{ "filters-but-no-output",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  "Component filters were set, but no output was generated at all. Likely none of the filtered components were found, "
+	  "try to relax the filters and ensure the input data is valid."
+	},
+
 	{ NULL, AS_ISSUE_SEVERITY_UNKNOWN, NULL }
 };
 
