@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2016-2021 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2022 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -98,7 +98,7 @@ asc_result_class_init (AscResultClass *klass)
  * asc_result_unit_ignored:
  * @result: an #AscResult instance.
  *
- * Returns: %TRUE if this result means the analyzed unit was ignored entirely..
+ * Returns: %TRUE if this result means the analyzed unit was ignored entirely.
  **/
 gboolean
 asc_result_unit_ignored (AscResult *result)
@@ -140,6 +140,24 @@ asc_result_hints_count (AscResult *result)
 	return count;
 }
 
+/**
+ * asc_result_is_ignored:
+ * @result: an #AscResult instance.
+ * @cpt: the component to check for.
+ *
+ * Check if an #AsComponent was set to be ignored in this result
+ * (usually due to errors).
+ *
+ * Returns: %TRUE if the component is ignored.
+ **/
+gboolean
+asc_result_is_ignored (AscResult *result, AsComponent *cpt)
+{
+	AscResultPrivate *priv = GET_PRIVATE (result);
+	return !g_hash_table_contains (priv->cpts,
+				       as_component_get_id (cpt));
+}
+
 /**
  * asc_result_get_bundle_kind:
  * @result: an #AscResult instance.
@@ -252,6 +270,35 @@ asc_result_get_hints (AscResult *result, const gchar *cid)
 	return g_hash_table_lookup (priv->hints, cid);
 }
 
+/**
+ * asc_result_fetch_hints_all:
+ * @result: an #AscResult instance.
+ *
+ * Get a list of all hints for all components that are registered with this result.
+ *
+ * Returns: (transfer container) (element-type AscHint) : An array of #AscHint
+ **/
+GPtrArray*
+asc_result_fetch_hints_all (AscResult *result)
+{
+	AscResultPrivate *priv = GET_PRIVATE (result);
+	GPtrArray *res;
+	GHashTableIter iter;
+	gpointer value;
+
+	res = g_ptr_array_new_full (g_hash_table_size (priv->hints),
+				    g_object_unref);
+
+	g_hash_table_iter_init (&iter, priv->hints);
+	while (g_hash_table_iter_next (&iter, NULL, &value)) {
+		GPtrArray *hints = value;
+		for (guint i = 0; i < hints->len; i++)
+			g_ptr_array_add (res,
+					 g_object_ref (ASC_HINT (g_ptr_array_index (hints, i))));
+	}
+	return res;
+}
+
 /**
  * asc_result_get_component_ids_with_hints:
  * @result: an #AscResult instance.
@@ -313,7 +360,7 @@ asc_result_update_component_gcid (AscResult *result, AsComponent *cpt, GBytes *b
 		g_autofree gchar *tmp = NULL;
 
 		old_hash_len = strlen (old_hash);
-		tmp = malloc(old_hash_len + data_len);
+		tmp = g_malloc (old_hash_len + data_len);
 		memcpy (tmp, old_hash, old_hash_len);
 		memcpy (tmp + old_hash_len, data, data_len);
 
@@ -471,6 +518,31 @@ asc_result_add_component_with_string (AscResult *result, AsComponent *cpt, const
 	return asc_result_add_component (result, cpt, bytes, error);
 }
 
+/**
+ * asc_result_remove_component_full:
+ * @result: an #AscResult instance.
+ * @cpt: The #AsComponent to remove.
+ * @remove_gcid: %TRUE if global component ID should be unregistered as well.
+ *
+ * Remove a component from the results set.
+ *
+ * Returns: %TRUE if the component was found and removed.
+ **/
+gboolean
+asc_result_remove_component_full (AscResult *result, AsComponent *cpt, gboolean remove_gcid)
+{
+	AscResultPrivate *priv = GET_PRIVATE (result);
+	gboolean ret;
+
+	ret = g_hash_table_remove (priv->cpts,
+				   as_component_get_id (cpt));
+	if (remove_gcid)
+		g_hash_table_remove (priv->gcids, as_component_get_id (cpt));
+	g_hash_table_remove (priv->mdata_hashes, cpt);
+
+	return ret;
+}
+
 /**
  * asc_result_remove_component:
  * @result: an #AscResult instance.
@@ -482,16 +554,51 @@ asc_result_add_component_with_string (AscResult *result, AsComponent *cpt, const
  **/
 gboolean
 asc_result_remove_component (AscResult *result, AsComponent *cpt)
+{
+	return asc_result_remove_component_full (result, cpt, TRUE);
+}
+
+/**
+ * asc_result_remove_hints_for_cid:
+ * @result: an #AscResult instance.
+ * @cid: The component ID
+ *
+ * Remove all hints that we have associated with the selected component-ID.
+ */
+void
+asc_result_remove_hints_for_cid (AscResult *result, const gchar *cid)
 {
 	AscResultPrivate *priv = GET_PRIVATE (result);
-	gboolean ret;
+	g_hash_table_remove (priv->hints, cid);
+}
 
-	ret = g_hash_table_remove (priv->cpts,
-				   as_component_get_id (cpt));
-	g_hash_table_remove (priv->gcids, as_component_get_id (cpt));
-	g_hash_table_remove (priv->mdata_hashes, cpt);
+/**
+ * asc_result_has_hint:
+ * @result: an #AscResult instance.
+ * @cpt: the #AsComponent to check
+ * @tag: the hint tag to check for
+ *
+ * Test if a hint tag is associated with a given component in this result.
+ *
+ * Returns: %TRUE if a hint with this tag exists for the selected component.
+ */
+gboolean
+asc_result_has_hint (AscResult *result, AsComponent *cpt, const gchar *tag)
+{
+	AscResultPrivate *priv = GET_PRIVATE (result);
+	GPtrArray *hints;
+	const gchar *cid = as_component_get_id (cpt);
 
-	return ret;
+	hints = g_hash_table_lookup (priv->hints, cid);
+	if (hints == NULL)
+		return FALSE;
+	for (guint i = 0; i < hints->len; i++) {
+		AscHint *hint = ASC_HINT (g_ptr_array_index (hints, i));
+		if (g_strcmp0 (asc_hint_get_tag (hint), tag) == 0)
+			return TRUE;
+	}
+
+	return FALSE;
 }
 
 /**
