@@ -41,6 +41,17 @@ inline QStringList valueWrap(gchar **strv)
     return res;
 }
 
+inline QStringList valueWrap(const gchar **strv)
+{
+    QStringList res;
+    if (strv == NULL)
+        return res;
+    for (uint i = 0; strv[i] != NULL; i++) {
+        res.append (QString::fromUtf8(strv[i]));
+    }
+    return res;
+}
+
 inline QStringList valueWrap(GPtrArray *array)
 {
     QStringList res;
@@ -66,12 +77,13 @@ inline QStringList valueWrap(GList *list)
 
 inline char ** stringListToCharArray(const QStringList& list)
 {
-    char **array = (char**) g_malloc(sizeof(char*) * list.size());
+    char **array = (char**) g_malloc(sizeof(char*) * list.size() + 1);
     for (int i = 0; i < list.size(); ++i) {
         const QByteArray string = list[i].toLocal8Bit();
         array[i] = (char*) g_malloc(sizeof(char) * (string.size() + 1));
         strcpy(array[i], string.constData());
     }
+    array[list.size()] = nullptr;
     return array;
 }
 
