@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016-2021 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2022 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -38,123 +38,27 @@
 
 using namespace AppStream;
 
-typedef QHash<Component::Kind, QString> KindMap;
-Q_GLOBAL_STATIC_WITH_ARGS(KindMap, kindMap, ( {
-    { Component::KindGeneric, QLatin1String("generic") },
-    { Component::KindDesktopApp, QLatin1String("desktop-application") },
-    { Component::KindConsoleApp, QLatin1String("console-application") },
-    { Component::KindWebApp, QLatin1String("web-application") },
-    { Component::KindAddon, QLatin1String("addon") },
-    { Component::KindFont, QLatin1String("font") },
-    { Component::KindCodec, QLatin1String("codec") },
-    { Component::KindInputmethod, QLatin1String("inputmethod") },
-    { Component::KindFirmware, QLatin1String("firmware") },
-    { Component::KindDriver, QLatin1String("driver") },
-    { Component::KindLocalization, QLatin1String("localization") },
-    { Component::KindService, QLatin1String("service") },
-    { Component::KindRepository, QLatin1String("repository") },
-    { Component::KindOperatingSystem, QLatin1String("operating-system") },
-    { Component::KindIconTheme, QLatin1String("icon-theme") },
-    { Component::KindRuntime, QLatin1String("runtime") },
-    { Component::KindUnknown, QLatin1String("unknown") }
-    }
-));
-
-QString Component::kindToString(Component::Kind kind) {
-    return kindMap->value(kind);
+QString Component::kindToString(Component::Kind kind)
+{
+    return QString::fromUtf8(as_component_kind_to_string(static_cast<AsComponentKind>(kind)));
 }
 
-Component::Kind Component::stringToKind(const QString& kindString) {
+Component::Kind Component::stringToKind(const QString& kindString)
+{
     if(kindString.isEmpty()) {
         return KindGeneric;
     }
-    if(kindString ==  QLatin1String("generic"))
-        return KindGeneric;
-
-    if (kindString == QLatin1String("desktop-application"))
-        return KindDesktopApp;
-
-    if (kindString == QLatin1String("console-application"))
-        return KindConsoleApp;
-
-    if (kindString == QLatin1String("web-application"))
-        return KindWebApp;
-
-    if (kindString == QLatin1String("addon"))
-        return KindAddon;
-
-    if (kindString == QLatin1String("font"))
-        return KindFont;
-
-    if (kindString == QLatin1String("codec"))
-        return KindCodec;
-
-    if (kindString==QLatin1String("inputmethod"))
-        return KindInputmethod;
-
-    if (kindString == QLatin1String("firmware"))
-        return KindFirmware;
-
-    if (kindString == QLatin1String("driver"))
-        return KindDriver;
-
-    if (kindString == QLatin1String("localization"))
-        return KindLocalization;
-
-    if (kindString == QLatin1String("service"))
-        return KindService;
-
-    if (kindString == QLatin1String("repository"))
-        return KindRepository;
-
-    if (kindString == QLatin1String("operating-system"))
-        return KindOperatingSystem;
-
-    if (kindString == QLatin1String("icon-theme"))
-        return KindIconTheme;
-
-    if (kindString == QLatin1String("runtime"))
-        return KindRuntime;
-
-    return KindUnknown;
-
+    return static_cast<Component::Kind>(as_component_kind_from_string(qPrintable(kindString)));
 }
 
-Component::UrlKind Component::stringToUrlKind(const QString& urlKindString) {
-    if (urlKindString == QLatin1String("homepage")) {
-        return UrlKindHomepage;
-    }
-    if (urlKindString == QLatin1String("bugtracker")) {
-        return UrlKindBugtracker;
-    }
-    if (urlKindString == QLatin1String("faq")) {
-        return UrlKindFaq;
-    }
-    if (urlKindString == QLatin1String("help")) {
-        return UrlKindHelp;
-    }
-    if (urlKindString == QLatin1String("donation")) {
-        return UrlKindDonation;
-    }
-    if (urlKindString == QLatin1String("contact")) {
-        return UrlKindContact;
-    }
-    return UrlKindUnknown;
+QString Component::urlKindToString(Component::UrlKind kind)
+{
+    return QString::fromUtf8(as_url_kind_to_string(static_cast<AsUrlKind>(kind)));
 }
 
-typedef QHash<Component::UrlKind, QString> UrlKindMap;
-Q_GLOBAL_STATIC_WITH_ARGS(UrlKindMap, urlKindMap, ({
-        { Component::UrlKindBugtracker, QLatin1String("bugtracker") },
-        { Component::UrlKindContact, QLatin1String("contact") },
-        { Component::UrlKindDonation, QLatin1String("donation") },
-        { Component::UrlKindFaq, QLatin1String("faq") },
-        { Component::UrlKindHelp, QLatin1String("help") },
-        { Component::UrlKindHomepage, QLatin1String("homepage") },
-        { Component::UrlKindUnknown, QLatin1String("unknown") },
-    }));
-
-QString Component::urlKindToString(Component::UrlKind kind) {
-    return urlKindMap->value(kind);
+Component::UrlKind Component::stringToUrlKind(const QString& urlKindString)
+{
+    return static_cast<Component::UrlKind>(as_url_kind_from_string(qPrintable(urlKindString)));
 }
 
 QString Component::scopeToString(Component::Scope scope)
@@ -201,6 +105,7 @@ Component& Component::operator=(const Component& other)
 Component::Component(Component&& other)
     : m_cpt(other.m_cpt)
 {
+    g_object_ref(other.m_cpt);
 }
 
 _AsComponent * AppStream::Component::asComponent() const
@@ -446,27 +351,55 @@ void AppStream::Component::addAddon(const AppStream::Component& addon)
     as_component_add_addon(m_cpt, addon.asComponent());
 }
 
-QList<Relation> Component::recommends() const
+QStringList Component::replaces() const
+{
+    return valueWrap(as_component_get_replaces(m_cpt));
+}
+
+void Component::addReplaces(const QString &cid)
+{
+    as_component_add_replaces(m_cpt, qPrintable(cid));
+}
+
+QList<Relation> Component::requires() const
+{
+    return requirements();
+}
+
+QList<Relation> Component::requirements() const
 {
     QList<AppStream::Relation> res;
 
-    auto recommends = as_component_get_recommends (m_cpt);
-    res.reserve(recommends->len);
-    for (uint i = 0; i < recommends->len; i++) {
-        auto rel = AS_RELATION (g_ptr_array_index (recommends, i));
+    auto requires = as_component_get_requires(m_cpt);
+    res.reserve(requires->len);
+    for (uint i = 0; i < requires->len; i++) {
+        auto rel = AS_RELATION (g_ptr_array_index(requires, i));
         res.append(Relation(rel));
     }
     return res;
 }
 
-QList<Relation> Component::requires() const
+QList<Relation> Component::recommends() const
 {
     QList<AppStream::Relation> res;
 
-    auto requires = as_component_get_requires (m_cpt);
-    res.reserve(requires->len);
-    for (uint i = 0; i < requires->len; i++) {
-        auto rel = AS_RELATION (g_ptr_array_index (requires, i));
+    auto recommends = as_component_get_recommends(m_cpt);
+    res.reserve(recommends->len);
+    for (uint i = 0; i < recommends->len; i++) {
+        auto rel = AS_RELATION (g_ptr_array_index(recommends, i));
+        res.append(Relation(rel));
+    }
+    return res;
+}
+
+QList<Relation> Component::supports() const
+{
+    QList<AppStream::Relation> res;
+
+    auto supports = as_component_get_supports(m_cpt);
+    res.reserve(supports->len);
+    for (uint i = 0; i < supports->len; i++) {
+        auto rel = AS_RELATION (g_ptr_array_index(supports, i));
         res.append(Relation(rel));
     }
     return res;
@@ -758,6 +691,31 @@ void Component::setNameVariantSuffix(const QString& variantSuffix, const QString
     as_component_set_name_variant_suffix(m_cpt, qPrintable(variantSuffix), lang.isEmpty()? NULL : qPrintable(lang));
 }
 
+bool Component::hasTag(const QString &ns, const QString &tagName)
+{
+    return as_component_has_tag(m_cpt, qPrintable(ns), qPrintable(tagName));
+}
+
+bool Component::addTag(const QString &ns, const QString &tagName)
+{
+    return as_component_add_tag(m_cpt, qPrintable(ns), qPrintable(tagName));
+}
+
+void Component::removeTag(const QString &ns, const QString &tagName)
+{
+    as_component_remove_tag(m_cpt, qPrintable(ns), qPrintable(tagName));
+}
+
+void Component::clearTags()
+{
+    as_component_clear_tags(m_cpt);
+}
+
+bool Component::isFree() const
+{
+    return as_component_is_free(m_cpt);
+}
+
 bool AppStream::Component::isIgnored() const
 {
     return as_component_is_ignored(m_cpt);
