@@ -88,6 +88,8 @@ class APPSTREAMQT_EXPORT Component {
             UrlKindDonation,
             UrlKindTranslate,
             UrlKindContact,
+            UrlKindVcsBrowser,
+            UrlKindContribute,
 
             // deprecated
             UrlTranslate   [[deprecated]] = UrlKindTranslate,
@@ -194,8 +196,13 @@ class APPSTREAMQT_EXPORT Component {
         QList<AppStream::Component> addons() const;
         void addAddon(const AppStream::Component& addon);
 
+        QStringList replaces() const;
+        void addReplaces(const QString& cid);
+
+        Q_DECL_DEPRECATED QList<AppStream::Relation> requires() const;
+        QList<AppStream::Relation> requirements() const;
         QList<AppStream::Relation> recommends() const;
-        QList<AppStream::Relation> requires() const;
+        QList<AppStream::Relation> supports() const;
         void addRelation(const AppStream::Relation &relation);
 
         QStringList languages() const;
@@ -264,6 +271,7 @@ class APPSTREAMQT_EXPORT Component {
         void removeTag(const QString &ns, const QString &tagName);
         void clearTags();
 
+        bool isFree() const;
         bool isIgnored() const;
         bool isValid() const;
 
