@@ -78,6 +78,11 @@ Pool::~Pool()
     // empty. needed for the scoped pointer for the private pointer
 }
 
+_AsPool *AppStream::Pool::asPool() const
+{
+    return d->pool;
+}
+
 bool AppStream::Pool::load()
 {
     g_autoptr(GError) error = nullptr;
@@ -175,6 +180,14 @@ QList<Component> Pool::componentsByExtends(const QString &extendedId) const
                                                              qPrintable(extendedId)));
 }
 
+QList<Component> Pool::componentsByBundleId(Bundle::Kind kind, const QString &extendedId, bool matchPrefix) const
+{
+    return cptArrayToQList(as_pool_get_components_by_bundle_id(d->pool,
+                                                               static_cast<AsBundleKind>(kind),
+                                                               qPrintable(extendedId),
+                                                               matchPrefix));
+}
+
 QList<AppStream::Component> Pool::search(const QString& term) const
 {
     return cptArrayToQList(as_pool_search(d->pool, qPrintable(term)));
