@@ -295,13 +295,13 @@ as_agreement_load_from_xml (AsAgreement *agreement, AsContext *ctx, xmlNode *nod
 	/* propagate context */
 	as_agreement_set_context (agreement, ctx);
 
-	prop = (gchar*) xmlGetProp (node, (xmlChar*) "type");
+	prop = as_xml_get_prop_value (node, "type");
 	if (prop != NULL) {
 		priv->kind = as_agreement_kind_from_string (prop);
 		g_free (prop);
 	}
 
-	prop = (gchar*) xmlGetProp (node, (xmlChar*) "version_id");
+	prop = as_xml_get_prop_value (node, "version_id");
 	if (prop != NULL) {
 		as_agreement_set_version_id (agreement, prop);
 		g_free (prop);
@@ -339,10 +339,9 @@ as_agreement_to_xml_node (AsAgreement *agreement, AsContext *ctx, xmlNode *root)
 	xmlNode *agnode;
 	guint i;
 
-	agnode = xmlNewChild (root, NULL, (xmlChar*) "agreement", (xmlChar*) "");
-	xmlNewProp (agnode, (xmlChar*) "type",
-		    (xmlChar*) as_agreement_kind_to_string (priv->kind));
-	xmlNewProp (agnode, (xmlChar*) "version_id", (xmlChar*) priv->version_id);
+	agnode = as_xml_add_node (root, "agreement");
+	as_xml_add_text_prop (agnode, "type", as_agreement_kind_to_string (priv->kind));
+	as_xml_add_text_prop (agnode, "version_id", priv->version_id);
 
 	for (i = 0; i < priv->sections->len; i++) {
 		AsAgreementSection *agsec = AS_AGREEMENT_SECTION (g_ptr_array_index (priv->sections, i));
