@@ -86,7 +86,7 @@ as_cache_section_new (const gchar *key)
 {
 	AsCacheSection *csec;
 	csec = g_new0 (AsCacheSection, 1);
-	csec->format_style = AS_FORMAT_STYLE_COLLECTION;
+	csec->format_style = AS_FORMAT_STYLE_CATALOG;
 	csec->key = g_strdup (key);
 	return csec;
 }
@@ -113,7 +113,7 @@ as_cache_section_cmp (gconstpointer a, gconstpointer b)
 	if (!s1->is_mask && s2->is_mask)
 		return -1;
 
-	/* sort collection metadata before metainfo data */
+	/* sort catalog metadata before metainfo data */
 	if (s1->format_style > s2->format_style)
 		return -1;
 	if (s1->format_style < s2->format_style)
@@ -163,7 +163,7 @@ as_cache_init (AsCache *cache)
 
 
 	priv->context = as_context_new ();
-	as_context_set_style (priv->context, AS_FORMAT_STYLE_COLLECTION);
+	as_context_set_style (priv->context, AS_FORMAT_STYLE_CATALOG);
 	/* we need to write some special tags only used in the cache */
 	as_context_set_internal_mode (priv->context, TRUE);
 
@@ -301,7 +301,7 @@ as_cache_set_locations (AsCache *cache, const gchar *system_cache_dir, const gch
  * as_cache_get_prefer_os_metainfo:
  * @cache: an #AsCache instance.
  *
- * Get whether metainfo data should be preferred over collection data for OS components.
+ * Get whether metainfo data should be preferred over catalog data for OS components.
  *
  * Returns: %TRUE if metainfo data is preferred.
  */
@@ -317,7 +317,7 @@ as_cache_get_prefer_os_metainfo (AsCache *cache)
  * @cache: an #AsCache instance.
  * @prefer_os_metainfo: Whether Metainfo data is preferred.
  *
- * Set whether metainfo data should be preferred over collection data for OS components.
+ * Set whether metainfo data should be preferred over catalog data for OS components.
  */
 void
 as_cache_set_prefer_os_metainfo (AsCache *cache, gboolean prefer_os_metainfo)
@@ -625,7 +625,7 @@ as_cache_builder_add_manifold_tokens (XbBuilderNode *root, AsComponent *cpt)
  * Convert a list of components into internal binary XML that we will store
  * on disk for fast querying.
  *
- * Returns: Valid collection XML metadata for internal cache use.
+ * Returns: Valid catalog XML metadata for internal cache use.
  */
 static XbSilo*
 as_cache_components_to_internal_xb (AsCache *cache,
@@ -1021,7 +1021,7 @@ as_cache_set_contents_for_path (AsCache *cache,
 
 	return as_cache_set_contents_internal (cache,
 						as_utils_guess_scope_from_path (filename),
-						AS_FORMAT_STYLE_COLLECTION,
+						AS_FORMAT_STYLE_CATALOG,
 						FALSE, /* no OS data */
 						cpts,
 						filename,
@@ -1252,7 +1252,7 @@ as_cache_load_section_for_path (AsCache *cache,
 	as_cache_load_section_internal (cache,
 					scope,
 					filename,
-					AS_FORMAT_STYLE_COLLECTION,
+					AS_FORMAT_STYLE_CATALOG,
 					FALSE,
 					is_outdated,
 					refinefn_user_data);
@@ -1354,7 +1354,7 @@ as_cache_add_masking_components (AsCache *cache, GPtrArray *cpts, GError **error
 	/* create new section */
 	mcsec = as_cache_section_new ("memory:volatile_mask");
 	mcsec->scope = AS_COMPONENT_SCOPE_USER;
-	mcsec->format_style = AS_FORMAT_STYLE_COLLECTION;
+	mcsec->format_style = AS_FORMAT_STYLE_CATALOG;
 	mcsec->fname = g_steal_pointer (&volatile_fname);
 	mcsec->is_mask = TRUE;
 
@@ -1746,7 +1746,7 @@ as_cache_get_components_by_provided_item (AsCache *cache, AsProvidedKind kind, c
  * @categories: List of category names.
  * @error: A #GError or %NULL.
  *
- * get a list of components in the selected categories.
+ * Get a list of components in the selected categories.
  *
  * Returns: (transfer full): An array of #AsComponent
  */
@@ -1762,6 +1762,14 @@ as_cache_get_components_by_categories (AsCache *cache, gchar **categories, GErro
 
 	xpath = g_string_new ("components/component/categories");
 	for (guint i = 0; categories[i] != NULL; i++) {
+		if (i >= 4) {
+			g_set_error_literal (error,
+						AS_CACHE_ERROR,
+						AS_CACHE_ERROR_PERMISSIONS,
+						"Due to limitations in libxmlb, we currently can not search for software "
+						"in more than 4 categories.");
+			return NULL;
+		}
 		g_string_append (xpath, "/category[text()=?]/..");
 		xb_value_bindings_bind_str (vbindings, i,
 					    categories[i],
@@ -1804,6 +1812,43 @@ as_cache_get_components_by_launchable (AsCache *cache, AsLaunchableKind kind, co
 					  error);
 }
 
+/**
+ * as_cache_get_components_by_bundle_id:
+ * @cache: An instance of #AsCache.
+ * @kind: Type of the bundle.
+ * @id: ID of the bundle.
+ * @error: A #GError or %NULL.
+ *
+ * Get components which are provided by a bundle with the given kind and ID.
+ *
+ * Returns: (transfer full): An array of #AsComponent
+ */
+
+GPtrArray*
+as_cache_get_components_by_bundle_id (AsCache *cache, AsBundleKind kind, const gchar *id, gboolean match_prefix, GError **error)
+{
+	g_auto(XbQueryContext) context = XB_QUERY_CONTEXT_INIT ();
+	g_autofree gchar *xpath = NULL;
+
+	if (kind == AS_BUNDLE_KIND_PACKAGE) {
+		xpath = g_strdup (match_prefix ? "components/component/pkgname[starts-with(text(),?)]/.."
+					       : "components/component/pkgname[text()=?]/..");
+	} else {
+		const gchar *match = match_prefix ? "components/component/bundle[@type='%s'][starts-with(text(),?)]/.."
+						  : "components/component/bundle[@type='%s'][text()=?]/..";
+		xpath = g_strdup_printf (match, as_bundle_kind_to_string (kind));
+	}
+
+	xb_value_bindings_bind_str (xb_query_context_get_bindings (&context),
+				    0, id, NULL);
+	return as_cache_query_components (cache,
+					  xpath,
+					  &context,
+					  0,
+					  FALSE,
+					  error);
+}
+
 typedef struct {
 	AsSearchTokenMatch	match_value;
 	XbQuery			*query;
