@@ -43,6 +43,9 @@
  * See also: #AsPool
  */
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+
 typedef struct
 {
 	gchar *id;
@@ -344,18 +347,4 @@ as_distro_details_new (void)
 	return AS_DISTRO_DETAILS (distro);
 }
 
-
-/**
- * as_get_current_distro_component_id:
- *
- * Returns the component-ID of the current distribution based on contents
- * of the `/etc/os-release` file.
- * This function is a shorthand for %as_distro_details_get_cid
- */
-gchar*
-as_get_current_distro_component_id (void)
-{
-	g_autoptr(AsDistroDetails) distro = as_distro_details_new ();
-	return g_strdup (as_distro_details_get_cid (distro));
-
-}
+#pragma GCC diagnostic pop
