@@ -216,11 +216,8 @@ as_launchable_to_xml_node (AsLaunchable *launchable, AsContext *ctx, xmlNode *ro
 		if (entry == NULL)
 			continue;
 
-		n = xmlNewTextChild (root, NULL,
-				     (xmlChar*) "launchable",
-				     (xmlChar*) entry);
-		xmlNewProp (n, (xmlChar*) "type",
-			    (xmlChar*) as_launchable_kind_to_string (priv->kind));
+		n = as_xml_add_text_node (root, "launchable", entry);
+		as_xml_add_text_prop (n, "type", as_launchable_kind_to_string (priv->kind));
 	}
 }
 
