@@ -96,11 +96,10 @@ static guint signals [SIGNAL_LAST] = { 0 };
 #define GET_PRIVATE(o) (as_pool_get_instance_private (o))
 
 /* TRANSLATORS: List of "grey-listed" words sperated with ";"
- * Do not translate this list directly. Instead,
- * provide a list of words in your language that people are likely
- * to include in a search but that should normally be ignored in
- * the search.
- */
+   Do not translate this list directly. Instead,
+   provide a list of words in your language that people are likely
+   to include in a search but that should normally be ignored in
+   the search. */
 #define AS_SEARCH_GREYLIST_STR _("app;application;package;program;programme;suite;tool")
 
 /* Prefixes of locations where system-wide AppStream catalog metadata can be found.
@@ -120,8 +119,8 @@ static gchar *METAINFO_DIR = "/usr/share/metainfo";
 /* cache key used for local metainfo / desktop-entry data */
 static gchar *LOCAL_METAINFO_CACHE_KEY = "local-metainfo";
 
-/* cache key used for AppStream collection metadata provided by the OS */
-static gchar *OS_COLLECTION_CACHE_KEY = "os-catalog";
+/* cache key used for AppStream catalog metadata provided by the OS */
+static gchar *OS_CATALOG_CACHE_KEY = "os-catalog";
 
 typedef struct {
 	AsFormatKind		format_kind;
@@ -355,7 +354,7 @@ as_pool_init (AsPool *pool)
 	priv->std_data_locations = g_hash_table_new_full (g_str_hash, g_str_equal,
 							  g_free, (GDestroyNotify) as_location_group_free);
 
-	/* user-defined collection metadata locations */
+	/* user-defined catalog metadata locations */
 	priv->extra_data_locations = g_hash_table_new_full (g_str_hash, g_str_equal,
 							    g_free, (GDestroyNotify) as_location_group_free);
 
@@ -375,7 +374,7 @@ as_pool_init (AsPool *pool)
 	priv->screenshot_service_url = as_distro_details_get_str (distro, "ScreenshotUrl");
 
 	/* set default pool flags */
-	priv->flags = AS_POOL_FLAG_LOAD_OS_COLLECTION |
+	priv->flags = AS_POOL_FLAG_LOAD_OS_CATALOG |
 		      AS_POOL_FLAG_LOAD_OS_METAINFO |
 		      AS_POOL_FLAG_LOAD_FLATPAK;
 
@@ -612,7 +611,7 @@ as_pool_register_flatpak_dir (AsPool *pool, const gchar *flatpak_root_dir, AsCom
 				cache_key = g_strconcat ("flatpak-", repo_name, "-", arch_name, NULL);
 				lgroup = as_location_group_new (pool,
 								scope,
-								AS_FORMAT_STYLE_COLLECTION,
+								AS_FORMAT_STYLE_CATALOG,
 								FALSE, /* no OS data, external from Flatpak */
 								cache_key);
 				lentry = as_location_group_add_dir (lgroup,
@@ -660,9 +659,9 @@ as_pool_detect_std_metadata_dirs (AsPool *pool, gboolean include_user_data)
 	/* create location groups and register them */
 	lgroup_catalog = as_location_group_new (pool,
 					     AS_COMPONENT_SCOPE_SYSTEM,
-					     AS_FORMAT_STYLE_COLLECTION,
+					     AS_FORMAT_STYLE_CATALOG,
 					     TRUE, /* is OS data */
-					     OS_COLLECTION_CACHE_KEY);
+					     OS_CATALOG_CACHE_KEY);
 	g_hash_table_insert (priv->std_data_locations,
 			     g_strdup (lgroup_catalog->cache_key),
 			     lgroup_catalog);
@@ -700,9 +699,9 @@ as_pool_detect_std_metadata_dirs (AsPool *pool, gboolean include_user_data)
 		}
 	}
 
-	/* add collection XML directories for the OS */
+	/* add catalog XML directories for the OS */
 	/* check if we are permitted to load this */
-	if (as_flags_contains (priv->flags, AS_POOL_FLAG_LOAD_OS_COLLECTION)) {
+	if (as_flags_contains (priv->flags, AS_POOL_FLAG_LOAD_OS_CATALOG)) {
 		for (guint i = 0; SYSTEM_CATALOG_METADATA_PREFIXES[i] != NULL; i++) {
 			g_autofree gchar *catalog_path = NULL;
 			g_autofree gchar *catalog_legacy_path = NULL;
@@ -880,7 +879,7 @@ as_pool_add_component_internal (AsPool *pool,
 			g_debug ("Merged desktop-entry data into metainfo data for '%s'.", cdid);
 			return TRUE;
 		}
-		if (existing_cpt_orig_kind == AS_ORIGIN_KIND_COLLECTION) {
+		if (existing_cpt_orig_kind == AS_ORIGIN_KIND_CATALOG) {
 			g_debug ("Ignored desktop-entry component '%s': We already have better data.", cdid);
 			return FALSE;
 		}
@@ -890,7 +889,7 @@ as_pool_add_component_internal (AsPool *pool,
 	if (as_flags_contains (priv->flags, AS_POOL_FLAG_PREFER_OS_METAINFO) &&
 	    (new_cpt_orig_kind == AS_ORIGIN_KIND_METAINFO)) {
 		/* update package info, metainfo files do never have this data.
-		 * (we hope that collection data was loaded first here, so the existing_cpt already contains
+		 * (we hope that catalog data was loaded first here, so the existing_cpt already contains
 		 *  the information we want - if that's not the case, no harm is done here) */
 		as_component_set_pkgnames (cpt, as_component_get_pkgnames (existing_cpt));
 		as_component_set_bundles_array (cpt, as_component_get_bundles (existing_cpt));
@@ -1029,13 +1028,13 @@ as_pool_clear2 (AsPool *pool, GError **error)
 }
 
 /**
- * as_pool_load_collection_data:
+ * as_pool_load_catalog_data:
  *
- * Load metadata from AppStream collection data directories,
+ * Load metadata from AppStream catalog data directories,
  * which are usually provided by some kind of software repository.
  */
 static gboolean
-as_pool_load_collection_data (AsPool *pool,
+as_pool_load_catalog_data (AsPool *pool,
 			      AsComponentRegistry *registry,
 			      AsLocationGroup *lgroup,
 			      GError **error)
@@ -1052,14 +1051,14 @@ as_pool_load_collection_data (AsPool *pool,
 	/* NOTE: Write-lock is held by the caller. */
 
 	/* do nothing if the group has the wrong format */
-	if (lgroup->format_style != AS_FORMAT_STYLE_COLLECTION)
+	if (lgroup->format_style != AS_FORMAT_STYLE_CATALOG)
 		return TRUE;
 
-	ptask = as_profile_start_literal (priv->profile, "AsPool:load_collection_data");
+	ptask = as_profile_start_literal (priv->profile, "AsPool:load_catalog_data");
 
 	/* prepare metadata parser */
 	metad = as_metadata_new ();
-	as_metadata_set_format_style (metad, AS_FORMAT_STYLE_COLLECTION);
+	as_metadata_set_format_style (metad, AS_FORMAT_STYLE_CATALOG);
 	as_metadata_set_locale (metad, priv->locale);
 
 	/* find AppStream metadata */
@@ -1575,8 +1574,8 @@ as_pool_loader_process_group (AsPool *pool,
 					lgroup,
 					lgroup->cache_key);
 
-	/* process collection data - we intentionally ignore errors here, and just skip any broken metadata*/
-	as_pool_load_collection_data (pool,
+	/* process catalog data - we intentionally ignore errors here, and just skip any broken metadata*/
+	as_pool_load_catalog_data (pool,
 					registry,
 					lgroup,
 					NULL);
@@ -2079,7 +2078,7 @@ as_pool_get_components_by_kind_gir (AsPool *pool, AsComponentKind kind)
  * @pool: An instance of #AsDatabase.
  * @categories: (array zero-terminated=1): An array of XDG categories to include.
  *
- * Return a list of components which are in one of the categories.
+ * Return a list of components which are in all of the categories.
  *
  * Returns: (transfer container) (element-type AsComponent): an array of #AsComponent objects which have been found.
  */
@@ -2237,6 +2236,62 @@ as_pool_get_components_by_extends_gir (AsPool *pool, const gchar *extended_id)
 	AS_PTR_ARRAY_RETURN_CLEAR_FREE_FUNC (as_pool_get_components_by_extends (pool, extended_id));
 }
 
+/**
+ * as_pool_get_components_by_bundle_id: (skip)
+ * @pool: An instance of #AsPool.
+ * @kind: The kind of the bundle we are looking for
+ * @bundle_id: The bundle ID to match, as specified in #AsBundle
+ * @match_prefix: %TRUE to match the ID by prefix, %FALSE to perform an absolute match.
+ *
+ * Find components that are provided by a bundle with a specific ID by its prefix.
+ * For example, given a AS_BUNDLE_KIND_FLATPAK and a bundle_id "org.kde.dolphin/",
+ * it will list all the components that bundle dolphin. If the bundle_id is
+ * "org.kde.dolphin/x86_64" it will give those with also the architecture.
+ *
+ * Since: 0.16.0
+ */
+GPtrArray*
+as_pool_get_components_by_bundle_id (AsPool *pool, AsBundleKind kind, const gchar *bundle_id, gboolean match_prefix)
+{
+	AsPoolPrivate *priv = GET_PRIVATE (pool);
+	g_autoptr(GError) tmp_error = NULL;
+	GPtrArray *result = NULL;
+	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_reader_locker_new (&priv->rw_lock);
+
+	result = as_cache_get_components_by_bundle_id (priv->cache, kind, bundle_id, match_prefix, &tmp_error);
+	if (result == NULL) {
+		g_warning ("Unable find components by bundle ID in session cache: %s", tmp_error->message);
+		return g_ptr_array_new_with_free_func (g_object_unref);
+	}
+
+	return result;
+}
+
+/**
+ * as_pool_get_components_by_bundle_id_gir: (rename-to as_pool_get_components_by_bundle_id)
+ * @pool: An instance of #AsPool.
+ * @kind: The kind of the bundle we are looking for
+ * @bundle_id: The bundle ID to match, as specified in #AsBundle
+ * @match_prefix: %TRUE to match the ID by prefix, %FALSE to perform an absolute match.
+ *
+ * Find components that are provided by a bundle with a specific ID by its prefix.
+ * For example, given a AS_BUNDLE_KIND_FLATPAK and a bundle_id "org.kde.dolphin/",
+ * it will list all the components that bundle dolphin. If the bundle_id is
+ * "org.kde.dolphin/x86_64" it will give those with also the architecture.
+ *
+ * This function fully transfers ownership of the returned container,
+ * to be used in GIR bindings.
+ *
+ * Returns: (transfer full) (element-type AsComponent): an array of #AsComponent objects.
+ *
+ * Since: 0.16.0
+ */
+GPtrArray*
+as_pool_get_components_by_bundle_id_gir (AsPool *pool, AsBundleKind kind, const gchar *bundle_id, gboolean match_prefix)
+{
+	AS_PTR_ARRAY_RETURN_CLEAR_FREE_FUNC (as_pool_get_components_by_bundle_id (pool, kind, bundle_id, match_prefix));
+}
+
 /**
  * as_user_search_term_valid:
  *
@@ -2527,7 +2582,7 @@ as_pool_get_locale (AsPool *pool)
  * as_pool_add_extra_data_location:
  * @pool: An instance of #AsPool.
  * @directory: An existing filesystem location.
- * @format_style: The expected format style of the metadata, e.g. %AS_FORMAT_STYLE_COLLECTION
+ * @format_style: The expected format style of the metadata, e.g. %AS_FORMAT_STYLE_CATALOG
  *
  * Add an additional non-standard location to the metadata pool where metadata will be read from.
  * If @directory contains a "xml", "xmls", "yaml" or "icons" subdirectory (or all of them),
@@ -2598,7 +2653,7 @@ as_pool_print_location_group_info (AsLocationGroup *lgroup)
 			if (lgroup->format_style == AS_FORMAT_STYLE_METAINFO)
 				format_kind_str = "MetaInfo XML";
 			else
-				format_kind_str = "Collection XML";
+				format_kind_str = "Catalog XML";
 		} else if (lentry->format_kind == AS_FORMAT_KIND_YAML) {
 			files = as_utils_find_files_matching (lentry->location, "*.yml*", FALSE, NULL);
 			format_kind_str = "YAML";
@@ -2703,7 +2758,7 @@ as_pool_print_std_data_locations_info_private (AsPool *pool, gboolean print_os_d
 void
 as_pool_add_metadata_location (AsPool *pool, const gchar *directory)
 {
-	as_pool_add_extra_data_location (pool, directory, AS_FORMAT_STYLE_COLLECTION);
+	as_pool_add_extra_data_location (pool, directory, AS_FORMAT_STYLE_CATALOG);
 }
 
 /**
@@ -2821,12 +2876,12 @@ as_pool_set_load_std_data_locations (AsPool *pool, gboolean enabled)
 	g_autoptr(GRWLockWriterLocker) locker = g_rw_lock_writer_locker_new (&priv->rw_lock);
 
 	if (enabled) {
-		as_flags_add (priv->flags, AS_POOL_FLAG_LOAD_OS_COLLECTION);
+		as_flags_add (priv->flags, AS_POOL_FLAG_LOAD_OS_CATALOG);
 		as_flags_add (priv->flags, AS_POOL_FLAG_LOAD_OS_DESKTOP_FILES);
 		as_flags_add (priv->flags, AS_POOL_FLAG_LOAD_OS_METAINFO);
 		as_flags_add (priv->flags, AS_POOL_FLAG_LOAD_FLATPAK);
 	} else {
-		as_flags_remove (priv->flags, AS_POOL_FLAG_LOAD_OS_COLLECTION);
+		as_flags_remove (priv->flags, AS_POOL_FLAG_LOAD_OS_CATALOG);
 		as_flags_remove (priv->flags, AS_POOL_FLAG_LOAD_OS_DESKTOP_FILES);
 		as_flags_remove (priv->flags, AS_POOL_FLAG_LOAD_OS_METAINFO);
 		as_flags_remove (priv->flags, AS_POOL_FLAG_LOAD_FLATPAK);
@@ -2837,7 +2892,7 @@ as_pool_set_load_std_data_locations (AsPool *pool, gboolean enabled)
  * as_pool_get_os_metadata_cache_age:
  * @pool: An instance of #AsPool.
  *
- * Get the age of the system cache for OS collection data.
+ * Get the age of the system cache for OS catalog data.
  */
 time_t
 as_pool_get_os_metadata_cache_age (AsPool *pool)
@@ -2846,7 +2901,7 @@ as_pool_get_os_metadata_cache_age (AsPool *pool)
 	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_reader_locker_new (&priv->rw_lock);
 	return as_cache_get_ctime (priv->cache,
 				   AS_COMPONENT_SCOPE_SYSTEM,
-				   OS_COLLECTION_CACHE_KEY,
+				   OS_CATALOG_CACHE_KEY,
 				   NULL);
 }
 
@@ -2897,7 +2952,7 @@ as_pool_set_cache_flags (AsPool *pool, AsCacheFlags flags)
 {
 	/* Legacy function that is just providing some compatibility glue */
 	if (as_flags_contains (flags, AS_CACHE_FLAG_USE_USER))
-		as_pool_remove_flags (pool, AS_POOL_FLAG_LOAD_OS_COLLECTION |
+		as_pool_remove_flags (pool, AS_POOL_FLAG_LOAD_OS_CATALOG |
 					    AS_POOL_FLAG_LOAD_OS_METAINFO);
 }
 
