@@ -50,20 +50,20 @@ struct _AsPoolClass
 /**
  * AsPoolFlags:
  * @AS_POOL_FLAG_NONE:			No flags.
- * @AS_POOL_FLAG_LOAD_OS_COLLECTION:	Load AppStream collection metadata from OS locations.
+ * @AS_POOL_FLAG_LOAD_OS_CATALOG:	Load AppStream catalog metadata from OS locations.
  * @AS_POOL_FLAG_LOAD_OS_METAINFO:	Load MetaInfo data from OS locations.
  * @AS_POOL_FLAG_LOAD_OS_DESKTOP_FILES:	Load components from desktop-entry files in OS locations.
- * @AS_POOL_FLAG_LOAD_FLATPAK:		Load AppStream collection metadata from Flatpak.
+ * @AS_POOL_FLAG_LOAD_FLATPAK:		Load AppStream catalog metadata from Flatpak.
  * @AS_POOL_FLAG_IGNORE_CACHE_AGE:	Load fresh data even if an up-o-date cache is available.
  * @AS_POOL_FLAG_RESOLVE_ADDONS:	Always resolve addons for returned components.
- * @AS_POOL_FLAG_PREFER_OS_METAINFO:	Prefer local metainfo data over the system-provided collection data. Useful for debugging.
+ * @AS_POOL_FLAG_PREFER_OS_METAINFO:	Prefer local metainfo data over the system-provided catalog data. Useful for debugging.
  * @AS_POOL_FLAG_MONITOR:		Monitor registered directories for changes, and auto-reload metadata if necessary.
  *
  * Flags controlling the metadata pool behavior.
  **/
 typedef enum {
 	AS_POOL_FLAG_NONE = 0,
-	AS_POOL_FLAG_LOAD_OS_COLLECTION    = 1 << 0,
+	AS_POOL_FLAG_LOAD_OS_CATALOG	   = 1 << 0,
 	AS_POOL_FLAG_LOAD_OS_METAINFO      = 1 << 1,
 	AS_POOL_FLAG_LOAD_OS_DESKTOP_FILES = 1 << 2,
 	AS_POOL_FLAG_LOAD_FLATPAK          = 1 << 3,
@@ -73,7 +73,8 @@ typedef enum {
 	AS_POOL_FLAG_MONITOR		   = 1 << 7,
 } AsPoolFlags;
 
-#define AS_POOL_FLAG_READ_COLLECTION AS_POOL_FLAG_LOAD_OS_COLLECTION
+#define AS_POOL_FLAG_LOAD_OS_COLLECTION AS_POOL_FLAG_LOAD_OS_CATALOG
+#define AS_POOL_FLAG_READ_COLLECTION AS_POOL_FLAG_LOAD_OS_CATALOG
 #define AS_POOL_FLAG_READ_METAINFO AS_POOL_FLAG_LOAD_OS_METAINFO
 #define AS_POOL_FLAG_READ_DESKTOP_FILES AS_POOL_FLAG_LOAD_OS_DESKTOP_FILES
 
@@ -155,6 +156,10 @@ GPtrArray		*as_pool_get_components_by_launchable (AsPool *pool,
 							       const gchar *id);
 GPtrArray		*as_pool_get_components_by_extends (AsPool *pool,
 							       const gchar *extended_id);
+GPtrArray		*as_pool_get_components_by_bundle_id (AsPool *pool,
+							      AsBundleKind kind,
+							      const gchar *bundle_id,
+							      gboolean match_prefix);
 GPtrArray		*as_pool_search (AsPool *pool,
 					 const gchar *search);
 gchar			**as_pool_build_search_tokens (AsPool *pool,
