@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2016-2021 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2022 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -32,6 +32,10 @@ AsContext		*as_release_get_context (AsRelease *release);
 void			as_release_set_context (AsRelease *release,
 						AsContext *context);
 
+gboolean		as_release_description_translatable (AsRelease *release);
+void			as_release_set_description_translatable (AsRelease *release,
+								 gboolean translatable);
+
 gboolean		as_release_load_from_xml (AsRelease *release,
 						  AsContext *ctx,
 						  xmlNode *node,
