@@ -207,7 +207,7 @@ as_suggested_load_from_xml (AsSuggested *suggested, AsContext *ctx, xmlNode *nod
 	xmlNode *iter;
 	g_autofree gchar *type_str = NULL;
 
-	type_str = (gchar*) xmlGetProp (node, (xmlChar*) "type");
+	type_str = as_xml_get_prop_value (node, "type");
 	priv->kind = as_suggested_kind_from_string (type_str);
 	if (priv->kind == AS_SUGGESTED_KIND_UNKNOWN) {
 		g_debug ("Found suggests tag of unknown type '%s' at %s:%li. Ignoring it.",
@@ -250,15 +250,12 @@ as_suggested_to_xml_node (AsSuggested *suggested, AsContext *ctx, xmlNode *root)
 	if ((priv->kind != AS_SUGGESTED_KIND_UPSTREAM) && (as_context_get_style (ctx) == AS_FORMAT_STYLE_METAINFO))
 		return;
 
-	node = xmlNewChild (root, NULL, (xmlChar*) "suggests", NULL);
-	xmlNewProp (node, (xmlChar*) "type",
-		    (xmlChar*) as_suggested_kind_to_string (priv->kind));
+	node = as_xml_add_node (root, "suggests");
+	as_xml_add_text_prop (node, "type", as_suggested_kind_to_string (priv->kind));
 
 	for (j = 0; j < priv->cpt_ids->len; j++) {
 		const gchar *cid = (const gchar*) g_ptr_array_index (priv->cpt_ids, j);
-		xmlNewTextChild (node, NULL,
-					(xmlChar*) "id",
-					(xmlChar*) cid);
+		as_xml_add_text_node (node, "id", cid);
 	}
 }
 
