@@ -32,6 +32,12 @@ G_BEGIN_DECLS
 #define AS_DATA_ID_WILDCARD	"*"
 #define	AS_DATA_ID_PARTS_COUNT	5
 
+/**
+ * as_str_equal0:
+ * Returns TRUE if strings are equal, ignoring NULL strings.
+ * This is a convenience wrapper around g_strcmp0
+ */
+#define as_str_equal0(str1, str2) (g_strcmp0 ((gchar*) str1,(gchar*) str2) == 0)
 
 /**
  * as_assign_string_safe:
@@ -46,7 +52,7 @@ G_BEGIN_DECLS
  */
 #define as_assign_string_safe(target, new_val) \
   G_STMT_START { \
-    if (G_LIKELY ((target) != (new_val))) { \
+    if (G_LIKELY (!as_str_equal0(target, new_val))) { \
 	g_free (target); \
 	target = g_strdup (new_val); \
       } \
@@ -71,26 +77,22 @@ G_BEGIN_DECLS
       } \
   } G_STMT_END
 
-/**
- * as_str_equal0:
- * Returns TRUE if strings are equal, ignoring NULL strings.
- * This is a convenience wrapper around g_strcmp0
- */
-#define as_str_equal0(str1,str2) (g_strcmp0 ((gchar*) str1,(gchar*) str2) == 0)
-
-#define AS_PTR_ARRAY_CLEAR_FREE_FUNC(array) \
-  AS_PTR_ARRAY_SET_FREE_FUNC(array, NULL)
 #define AS_PTR_ARRAY_SET_FREE_FUNC(array, func) \
   G_STMT_START { \
     if ((array) != NULL) \
       g_ptr_array_set_free_func ((array), (GDestroyNotify)(func)); \
   } G_STMT_END
+#define AS_PTR_ARRAY_CLEAR_FREE_FUNC(array) \
+  AS_PTR_ARRAY_SET_FREE_FUNC(array, NULL)
 #define AS_PTR_ARRAY_STEAL_FULL(arrptr) \
   ({ AS_PTR_ARRAY_CLEAR_FREE_FUNC (*(arrptr)); \
      g_steal_pointer ((arrptr)); })
 #define AS_PTR_ARRAY_RETURN_CLEAR_FREE_FUNC(array) \
-  ({ AS_PTR_ARRAY_CLEAR_FREE_FUNC (array); \
-     return array; })
+  G_STMT_START { \
+	GPtrArray *_tmp_array = (array); \
+	AS_PTR_ARRAY_CLEAR_FREE_FUNC (_tmp_array); \
+	return _tmp_array; \
+  } G_STMT_END
 
 /**
  * AsMarkupKind:
