@@ -251,7 +251,7 @@ as_description_markup_convert (const gchar *markup, AsMarkupKind to_kind, GError
 
 		if (g_strcmp0 ((gchar*) iter->name, "p") == 0) {
 			g_autofree gchar *clean_text = NULL;
-			g_autofree gchar *text_content = (gchar*) xmlNodeGetContent (iter);
+			g_autofree gchar *text_content = as_xml_get_node_value_raw (iter);
 
 			/* Apparently the element is empty, which is odd. But we better add it instead
 			 * of completely ignoring it. */
@@ -266,8 +266,10 @@ as_description_markup_convert (const gchar *markup, AsMarkupKind to_kind, GError
 
 			if (to_kind == AS_MARKUP_KIND_MARKDOWN) {
 				g_auto(GStrv) spl = as_markup_strsplit_words (clean_text, 100);
-				for (guint i = 0; spl[i] != NULL; i++)
-					g_string_append (str, spl[i]);
+				if (spl != NULL) {
+					for (guint i = 0; spl[i] != NULL; i++)
+						g_string_append (str, spl[i]);
+				}
 			} else {
 				g_string_append_printf (str, "%s\n", clean_text);
 			}
@@ -291,7 +293,7 @@ as_description_markup_convert (const gchar *markup, AsMarkupKind to_kind, GError
 				if (g_strcmp0 ((gchar*) iter2->name, "li") == 0) {
 					g_auto(GStrv) spl = NULL;
 					g_autofree gchar *clean_item = NULL;
-					g_autofree gchar *item_content = (gchar*) xmlNodeGetContent (iter2);
+					g_autofree gchar *item_content = as_xml_get_node_value_raw (iter2);
 					entry_no++;
 
 					/* Apparently the item text is empty, which is odd.
@@ -310,9 +312,11 @@ as_description_markup_convert (const gchar *markup, AsMarkupKind to_kind, GError
 
 					/* break to 100 chars, leaving room for the dot/indent */
 					spl = as_markup_strsplit_words (clean_item, 100 - 4);
-					g_string_append_printf (str, " %s %s", item_c, spl[0]);
-					for (guint i = 1; spl[i] != NULL; i++)
-						g_string_append_printf (str, "   %s", spl[i]);
+					if (spl != NULL) {
+						g_string_append_printf (str, " %s %s", item_c, spl[0]);
+						for (guint i = 1; spl[i] != NULL; i++)
+							g_string_append_printf (str, "   %s", spl[i]);
+					}
 				} else {
 					/* only <li> is valid in lists */
 					ret = FALSE;
@@ -404,6 +408,36 @@ as_iso8601_to_datetime (const gchar *iso_date)
 	return g_date_time_new_utc (dmy[0], dmy[1], dmy[2], 0, 0, 0);
 }
 
+/**
+ * as_str_verify_integer:
+ * @str: The string to test.
+ * @min_value: Minimal value to be considered valid, e.g. %G_MININT64
+ * @max_value: Maximum value to be considered valie, e.g. %G_MAXINT64
+ *
+ * Verify that a string is an integer in the given range.
+ * Unlike strtoll(), this function will only pass if the whole string
+ * consists of numbers, and will not succeed if the string has a text suffix.
+ *
+ * Returns: %TRUE if verified correctly according to the set conditions, %FALSE otherwise.
+ */
+gboolean
+as_str_verify_integer (const gchar *str, gint64 min_value, gint64 max_value)
+{
+	gchar *endptr;
+	gint64 res;
+	g_return_val_if_fail (min_value < max_value, FALSE);
+
+	if (as_is_empty (str))
+		return FALSE;
+
+	res = g_ascii_strtoll (str, &endptr, 10);
+	/* check if we used the whole string for conversion */
+	if (endptr[0] != '\0')
+		return FALSE;
+
+	return res >= min_value && res <= max_value;
+}
+
 /**
  * as_utils_delete_dir_recursive:
  * @dirname: Directory to remove
@@ -536,6 +570,7 @@ out:
 			g_debug ("Error while searching for files in %s: %s", dir, tmp_error->message);
 		else
 			g_propagate_error (error, tmp_error);
+		g_error_free (tmp_error);
 		g_ptr_array_unref (list);
 		return NULL;
 	}
@@ -611,18 +646,15 @@ as_get_current_locale (void)
 	locale_names = g_get_language_names ();
 
 	if (g_strstr_len (locale_names[0], -1, "_") == NULL) {
-		/* The locale doesn't have a region code - see if LANG has more to offer.
-		 * Some users expect LANG to take priority, and PackageKit uses region codes
-		 * as well since frontends submit them (based on LANG).
-		 * So if we don't have them in LANGUAGE but do have them in LANG, we have
-		 * different localization depending on how the application was launched as well as
-		 * multiple caches on systems which generate them via a backend in PackageKit. */
+		/* The locale doesn't have a region code - see if LANG has more to offer. */
 		const gchar *env_lang = g_getenv ("LANG");
 		if ((env_lang != NULL) && (g_strstr_len (env_lang, -1, "_") != NULL))
 			locale = env_lang;
 	}
 	if (locale == NULL)
 		locale = locale_names[0];
+	if (locale == NULL)
+		locale = g_strdup ("C");
 
 	/* return active locale without UTF-8 suffix, UTF-8 is default in AppStream */
 	return as_locale_strip_encoding (locale);
@@ -941,10 +973,8 @@ as_utils_locale_to_language (const gchar *locale)
 const gchar*
 as_ptr_array_find_string (GPtrArray *array, const gchar *value)
 {
-	const gchar *tmp;
-	guint i;
-	for (i = 0; i < array->len; i++) {
-		tmp = g_ptr_array_index (array, i);
+	for (guint i = 0; i < array->len; i++) {
+		const gchar *tmp = g_ptr_array_index (array, i);
 		if (g_strcmp0 (tmp, value) == 0)
 			return tmp;
 	}
@@ -1051,7 +1081,7 @@ as_utils_search_token_valid (const gchar *token)
  * Perform a sanity check to ensure GResource can be loaded.
  */
 void
-as_utils_ensure_resources ()
+as_utils_ensure_resources (void)
 {
 	static GMutex mutex;
 	GResource *resource = NULL;
@@ -2001,7 +2031,7 @@ as_utils_install_metadata_file_internal (const gchar *filename,
 			g_set_error (error,
 				     AS_UTILS_ERROR,
 				     AS_UTILS_ERROR_FAILED,
-				     "Name of metadata collection file is invalid %s",
+				     "Name of metadata catalog file is invalid %s",
 				     basename);
 			return FALSE;
 		}
@@ -2026,7 +2056,7 @@ as_utils_install_metadata_file_internal (const gchar *filename,
 		if (!as_metadata_parse_file (mdata, file_dest, AS_FORMAT_KIND_XML, error))
 			return FALSE;
 		as_metadata_set_origin (mdata, origin);
-		if (!as_metadata_save_collection (mdata, path_dest, AS_FORMAT_KIND_XML, error))
+		if (!as_metadata_save_catalog (mdata, path_dest, AS_FORMAT_KIND_XML, error))
 			return FALSE;
 	}
 
@@ -2072,7 +2102,7 @@ as_utils_install_icon_tarball (AsMetadataLocation location,
  * @destdir: the destdir to use, or %NULL
  * @error: A #GError or %NULL
  *
- * Installs an AppStream MetaInfo, AppStream Metadata Collection or AppStream Icon tarball file
+ * Installs an AppStream MetaInfo, AppStream Metadata Catalog or AppStream Icon tarball file
  * to the right place on the filesystem.
  * Please note that this function does almost no validation and may guess missing values such
  * as icon sizes and origin names.
@@ -2108,7 +2138,7 @@ as_utils_install_metadata_file (AsMetadataLocation location,
 		destdir = "";
 
 	switch (as_metadata_file_guess_style (filename)) {
-	case AS_FORMAT_STYLE_COLLECTION:
+	case AS_FORMAT_STYLE_CATALOG:
 		if (g_strstr_len (filename, -1, ".yml.gz") != NULL) {
 			path = g_build_filename (as_metadata_location_get_prefix (location),
 						 "swcatalog", "yaml", NULL);
