@@ -42,8 +42,7 @@
 gchar*
 as_xml_get_node_value (const xmlNode *node)
 {
-	gchar *content;
-	content = (gchar*) xmlNodeGetContent (node);
+	gchar *content = as_xml_get_node_value_raw (node);
 	if (content != NULL)
 		as_strstripnl (content);
 
@@ -60,8 +59,7 @@ as_xml_get_node_value (const xmlNode *node)
 GRefString*
 as_xml_get_node_value_refstr (const xmlNode *node)
 {
-	g_autofree gchar *content = NULL;
-	content = (gchar*) xmlNodeGetContent (node);
+	g_autofree gchar *content = as_xml_get_node_value_raw (node);
 	if (content != NULL)
 		as_strstripnl (content);
 	if (content == NULL)
@@ -141,8 +139,7 @@ as_xml_get_node_locale_match (AsContext *ctx, xmlNode *node)
 	/* If we are here, we haven't found a matching locale.
 	 * In that case, we return %NULL to indicate that this element should not be added.
 	 */
-	g_free (lang);
-	lang = NULL;
+	g_free (g_steal_pointer (&lang));
 
 out:
 	return lang;
@@ -452,7 +449,7 @@ typedef struct
  * as_xml_metainfo_desc_parse_helper_new: (skip)
  **/
 static AsXMLMetaInfoDescParseHelper*
-as_xml_metainfo_desc_parse_helper_new ()
+as_xml_metainfo_desc_parse_helper_new (void)
 {
 	AsXMLMetaInfoDescParseHelper *helper = g_slice_new0 (AsXMLMetaInfoDescParseHelper);
 	helper->data = g_string_new ("");
@@ -602,12 +599,12 @@ as_xml_parse_metainfo_description_node (AsContext *ctx, xmlNode *node, GHashTabl
 }
 
 /**
- * as_xml_add_description_collection_mode_helper:
+ * as_xml_add_description_catalog_mode_helper:
  *
- * Add the description markup for AppStream collection XML to the tree.
+ * Add the description markup for AppStream catalog XML to the tree.
  */
 static gboolean
-as_xml_add_description_collection_mode_helper (xmlNode *parent, const gchar *description_markup, const gchar *lang)
+as_xml_add_description_catalog_mode_helper (xmlNode *parent, const gchar *description_markup, const gchar *lang)
 {
 	xmlNode *dnode;
 	xmlNode *cnode;
@@ -700,7 +697,7 @@ as_xml_add_description_node (AsContext *ctx, xmlNode *root, GHashTable *desc_tab
 
 		dnode = xmlNewChild (root, NULL, (xmlChar*) "description", NULL);
 		if (!mi_translatable)
-			as_xml_add_text_prop (dnode, "translatable", "no");
+			as_xml_add_text_prop (dnode, "translate", "no");
 
 		cnode = dnode;
 		do {
@@ -744,7 +741,7 @@ as_xml_add_description_node (AsContext *ctx, xmlNode *root, GHashTable *desc_tab
 			} while (as_xml_markup_parse_helper_next (helper));
 		}
 	} else {
-		/* we have a collection XML file, so write in that format (which is much faster and easier to do) */
+		/* we have a catalog XML file, so write in that format (which is much faster and easier to do) */
 		for (GList *link = keys; link != NULL; link = link->next) {
 			const gchar *locale = (const gchar*) link->data;
 			const gchar *desc_markup = g_hash_table_lookup (desc_table, locale);
@@ -752,7 +749,7 @@ as_xml_add_description_node (AsContext *ctx, xmlNode *root, GHashTable *desc_tab
 			if (as_is_cruft_locale (locale))
 				continue;
 
-			as_xml_add_description_collection_mode_helper (root, desc_markup, locale);
+			as_xml_add_description_catalog_mode_helper (root, desc_markup, locale);
 		}
 	}
 }
@@ -1092,7 +1089,7 @@ as_xml_parse_document (const gchar *data, gssize len, GError **error)
 }
 
 /**
- * as_xml_node_to_str:
+ * as_xml_node_free_to_str:
  * @root: The document root node.
  *
  * Converts an XML node into its textural representation.
@@ -1102,7 +1099,7 @@ as_xml_parse_document (const gchar *data, gssize len, GError **error)
  * Returns: XML metadata.
  */
 gchar*
-as_xml_node_to_str (xmlNode *root, GError **error)
+as_xml_node_free_to_str (xmlNode *root, GError **error)
 {
 	xmlDoc *doc;
 	gchar *xmlstr = NULL;
