@@ -30,9 +30,10 @@ eatmydata apt-get install -yq --no-install-recommends \
     libyaml-dev \
     libxmlb-dev \
     liblzma-dev \
+    libzstd-dev \
     libcurl4-gnutls-dev \
+    libsystemd-dev \
     gtk-doc-tools \
-    itstool \
     libgirepository1.0-dev \
     qtbase5-dev \
     xmlto \
