@@ -18,10 +18,11 @@
  * along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <config.h>
 #include <glib.h>
 #include "appstream.h"
 #include "as-component-private.h"
-#include "as-distro-details-private.h"
+#include "as-system-info-private.h"
 #include "as-utils-private.h"
 
 #include "as-test-utils.h"
@@ -221,7 +222,7 @@ test_component (void)
 	metad = as_metadata_new ();
 	as_metadata_add_component (metad, cpt);
 	str = as_metadata_component_to_metainfo (metad, AS_FORMAT_KIND_XML, NULL);
-	str2 = as_metadata_components_to_collection (metad, AS_FORMAT_KIND_XML, NULL);
+	str2 = as_metadata_components_to_catalog (metad, AS_FORMAT_KIND_XML, NULL);
 	g_debug ("%s", str2);
 
 	g_assert_cmpstr (str, ==, "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"
@@ -232,7 +233,7 @@ test_component (void)
 				  "  <pkgname>fedex</pkgname>\n"
 				  "</component>\n");
 	g_assert_cmpstr (str2, ==, "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"
-				   "<components version=\"0.14\">\n"
+				   "<components version=\"0.16\">\n"
 				   "  <component type=\"desktop-application\">\n"
 				   "    <id>org.example.test.desktop</id>\n"
 				   "    <name>Test</name>\n"
@@ -626,7 +627,7 @@ test_desktop_entry_convert (void)
 	g_assert_no_error (error);
 	g_free (tmp);
 
-	tmp = as_metadata_components_to_collection (metad, AS_FORMAT_KIND_XML, &error);
+	tmp = as_metadata_components_to_catalog (metad, AS_FORMAT_KIND_XML, &error);
 	g_assert_no_error (error);
 	g_assert_true (as_test_compare_lines (tmp, expected_xml));
 	g_free (tmp);
@@ -712,29 +713,50 @@ test_version_compare (void)
 	g_assert_cmpint (as_vercmp_simple ("9+", "10"), <, 0);
 	g_assert_cmpint (as_vercmp_simple ("9half", "10"), <, 0);
 	g_assert_cmpint (as_vercmp_simple ("9.5", "10"), <, 0);
+
+	/* test match */
+	g_assert_true (as_vercmp_test_match ("1", AS_RELATION_COMPARE_LT, "2", AS_VERCMP_FLAG_NONE));
+	g_assert_true (as_vercmp_test_match ("2", AS_RELATION_COMPARE_GT, "1", AS_VERCMP_FLAG_NONE));
+	g_assert_true (as_vercmp_test_match ("3", AS_RELATION_COMPARE_EQ, "3", AS_VERCMP_FLAG_NONE));
+	g_assert_true (as_vercmp_test_match ("4", AS_RELATION_COMPARE_NE, "3", AS_VERCMP_FLAG_NONE));
+	g_assert_true (as_vercmp_test_match ("4", AS_RELATION_COMPARE_GE, "3", AS_VERCMP_FLAG_NONE));
+	g_assert_false (as_vercmp_test_match ("5", AS_RELATION_COMPARE_GE, "6", AS_VERCMP_FLAG_NONE));
 }
 
 /**
- * test_distro_details:
+ * test_system_info:
  *
- * Test fetching distro details.
+ * Test fetching OS details and device info.
  */
 static void
-test_distro_details (void)
+test_system_info (void)
 {
+	g_autoptr(AsSystemInfo) sysinfo = as_system_info_new ();
 	g_autofree gchar *osrelease_fname = NULL;
-	g_autoptr(AsDistroDetails) distro = as_distro_details_new ();
+	g_autofree gchar *dev_name = NULL;
+	g_autoptr(GError) error = NULL;
 
 	osrelease_fname = g_build_filename (datadir, "os-release-1", NULL);
 
-	as_distro_details_load_data (distro, osrelease_fname, NULL);
+	as_system_info_load_os_release (sysinfo, osrelease_fname);
 
-	g_assert_cmpstr (as_distro_details_get_name (distro), ==, "Debian GNU/Linux");
-	g_assert_cmpstr (as_distro_details_get_version (distro), ==, "10.0");
-	g_assert_cmpstr (as_distro_details_get_homepage (distro), ==, "https://www.debian.org/");
+	g_assert_cmpstr (as_system_info_get_os_name (sysinfo), ==, "Debian GNU/Linux");
+	g_assert_cmpstr (as_system_info_get_os_version (sysinfo), ==, "10.0");
+	g_assert_cmpstr (as_system_info_get_os_homepage (sysinfo), ==, "https://www.debian.org/");
 
-	g_assert_cmpstr (as_distro_details_get_id (distro), ==, "debian");
-	g_assert_cmpstr (as_distro_details_get_cid (distro), ==, "org.debian.debian");
+	g_assert_cmpstr (as_system_info_get_os_id (sysinfo), ==, "debian");
+	g_assert_cmpstr (as_system_info_get_os_cid (sysinfo), ==, "org.debian.debian");
+
+	g_assert_nonnull (as_system_info_get_kernel_name (sysinfo));
+	g_assert_nonnull (as_system_info_get_kernel_version (sysinfo));
+
+	g_assert_cmpint (as_system_info_get_memory_total (sysinfo), >=, 128);
+
+	/* We can't properly test this as most build environments lack the udev hardware database.
+	 * We still run the code for potential leak detection etc. */
+	dev_name = as_system_info_get_device_name_for_modalias (sysinfo, "usb:v1130p0202d*", FALSE, &error);
+	if (error != NULL)
+		g_error_free (g_steal_pointer (&error));
 }
 
 /**
@@ -1031,7 +1053,7 @@ main (int argc, char **argv)
 	g_test_add_func ("/AppStream/ReadDesktopEntry", test_read_desktop_entry_simple);
 	g_test_add_func ("/AppStream/ConvertDesktopEntry", test_desktop_entry_convert);
 	g_test_add_func ("/AppStream/VersionCompare", test_version_compare);
-	g_test_add_func ("/AppStream/DistroDetails", test_distro_details);
+	g_test_add_func ("/AppStream/SystemInfo", test_system_info);
 	g_test_add_func ("/AppStream/rDNSConvert", test_rdns_convert);
 	g_test_add_func ("/AppStream/URIToBasename", test_filebasename_from_uri);
 	g_test_add_func ("/AppStream/ContentRating/Mapings", test_content_rating_mappings);
