@@ -19,6 +19,7 @@
  */
 
 #include <config.h>
+#include <locale.h>
 #include <glib.h>
 #include <glib/gstdio.h>
 #include <glib/gprintf.h>
@@ -117,10 +118,10 @@ test_get_sampledata_pool (gboolean use_caches)
 	g_assert_nonnull (cache_dummy_dir);
 
 	/* create AsPool and load sample metadata */
-	mdata_dir = g_build_filename (datadir, "collection", NULL);
+	mdata_dir = g_build_filename (datadir, "catalog", NULL);
 
 	pool = as_pool_new ();
-	as_pool_add_extra_data_location (pool, mdata_dir, AS_FORMAT_STYLE_COLLECTION);
+	as_pool_add_extra_data_location (pool, mdata_dir, AS_FORMAT_STYLE_CATALOG);
 	as_pool_set_locale (pool, "C");
 
 	flags = as_pool_get_flags (pool);
@@ -162,7 +163,7 @@ as_assert_component_lists_equal (GPtrArray *cpts_a, GPtrArray *cpts_b)
 		as_metadata_add_component (metad, cpt);
 	}
 
-	cpts_a_xml = as_metadata_components_to_collection (metad, AS_FORMAT_KIND_XML, &error);
+	cpts_a_xml = as_metadata_components_to_catalog (metad, AS_FORMAT_KIND_XML, &error);
 	g_assert_no_error (error);
 
 	as_metadata_clear_components (metad);
@@ -176,7 +177,7 @@ as_assert_component_lists_equal (GPtrArray *cpts_a, GPtrArray *cpts_b)
 		as_metadata_add_component (metad, cpt);
 	}
 
-	cpts_b_xml = as_metadata_components_to_collection (metad, AS_FORMAT_KIND_XML, &error);
+	cpts_b_xml = as_metadata_components_to_catalog (metad, AS_FORMAT_KIND_XML, &error);
 	g_assert_no_error (error);
 
 	g_assert_true (as_test_compare_lines (cpts_a_xml, cpts_b_xml));
@@ -202,7 +203,7 @@ test_cache (void)
 	g_autofree gchar *xmldata_postcache = NULL;
 	g_autofree gchar *cache_testpath = g_build_filename (cache_dummy_dir, "ctest", NULL);
 
-	mdata_dir = g_build_filename (datadir, "collection", "xml", NULL);
+	mdata_dir = g_build_filename (datadir, "catalog", "xml", NULL);
 
 	xml_files = as_utils_find_files_matching (mdata_dir, "*.xml", FALSE, &error);
 	g_assert_no_error (error);
@@ -210,7 +211,7 @@ test_cache (void)
 
 	mdata = as_metadata_new ();
 	as_metadata_set_locale (mdata, "C");
-	as_metadata_set_format_style (mdata, AS_FORMAT_STYLE_COLLECTION);
+	as_metadata_set_format_style (mdata, AS_FORMAT_STYLE_CATALOG);
 
 	for (guint i = 0; i < xml_files->len; i++) {
 		g_autoptr(GFile) file = NULL;
@@ -250,7 +251,7 @@ test_cache (void)
 		AsComponent *cpt = AS_COMPONENT (g_ptr_array_index (cpts_pre, i));
 		as_metadata_add_component (mdata, cpt);
 	}
-	xmldata_precache = as_metadata_components_to_collection (mdata, AS_FORMAT_KIND_XML, &error);
+	xmldata_precache = as_metadata_components_to_catalog (mdata, AS_FORMAT_KIND_XML, &error);
 	g_assert_no_error (error);
 
 	/* create new cache for writing */
@@ -290,7 +291,7 @@ test_cache (void)
 		as_metadata_add_component (mdata, cpt);
 	}
 
-	xmldata_postcache = as_metadata_components_to_collection (mdata, AS_FORMAT_KIND_XML, &error);
+	xmldata_postcache = as_metadata_components_to_catalog (mdata, AS_FORMAT_KIND_XML, &error);
 	g_assert_no_error (error);
 
 	g_assert_true (as_test_compare_lines (xmldata_precache, xmldata_postcache));
@@ -395,6 +396,12 @@ test_pool_read (void)
 
 	g_clear_pointer (&result, g_ptr_array_unref);
 
+	/* by bundle ID */
+	result = as_pool_get_components_by_bundle_id (dpool, AS_BUNDLE_KIND_LIMBA, "neverball-", TRUE);
+	print_cptarray (result);
+	g_assert_cmpint (result->len, ==, 1);
+	g_clear_pointer (&result, g_ptr_array_unref);
+
 	/* test a component in a different file, with no package but a bundle instead */
 	cpt_a = _as_get_single_component_by_cid (dpool, "org.neverball.Neverball");
 	g_assert_nonnull (cpt_a);
@@ -961,7 +968,7 @@ test_pool_autoreload (void)
 	g_mkdir_with_parents (tmpdir, 0700);
 
 	/* add new data directory */
-	as_pool_add_extra_data_location (pool, tmpdir, AS_FORMAT_STYLE_COLLECTION);
+	as_pool_add_extra_data_location (pool, tmpdir, AS_FORMAT_STYLE_CATALOG);
 
 	/* ensure cache is empty */
 	result = as_pool_get_components_by_id (pool, "org.inkscape.Inkscape");
@@ -970,7 +977,7 @@ test_pool_autoreload (void)
 
 	/* add data and wait for auto-reload */
 	data_changed = FALSE;
-	src_datafile1 = g_build_filename (datadir, "collection", "xml", "foobar-1.xml", NULL);
+	src_datafile1 = g_build_filename (datadir, "catalog", "xml", "foobar-1.xml", NULL);
 	dst_datafile1 = g_build_filename (tmpdir, "foobar-1.xml", NULL);
 	ret = as_copy_file (src_datafile1, dst_datafile1, &error);
 	g_assert_no_error (error);
@@ -987,7 +994,7 @@ test_pool_autoreload (void)
 
 	/* add more data */
 	data_changed = FALSE;
-	src_datafile2 = g_build_filename (datadir, "collection", "xml", "lvfs-gdpr.xml", NULL);
+	src_datafile2 = g_build_filename (datadir, "catalog", "xml", "lvfs-gdpr.xml", NULL);
 	dst_datafile2 = g_build_filename (tmpdir, "lvfs-gdpr.xml", NULL);
 	ret = as_copy_file (src_datafile2, dst_datafile2, &error);
 	g_assert_no_error (error);
@@ -1032,6 +1039,10 @@ main (int argc, char **argv)
 		return 1;
 	}
 
+	/* ensure locale is reset, to avoid interference when stemming is enabled & tested */
+	if (setlocale (LC_ALL, "C.UTF-8") == NULL)
+		g_warning ("Failed to set locale to C.UTF-8");
+
 	datadir = argv[1];
 	g_assert_nonnull (datadir);
 	datadir = g_build_filename (datadir, "samples", NULL);
