@@ -77,7 +77,7 @@ as_xml_test_serialize (AsComponent *cpt, AsFormatStyle mode)
 		data = as_metadata_component_to_metainfo (metad, AS_FORMAT_KIND_XML, &error);
 		g_assert_no_error (error);
 	} else {
-		data = as_metadata_components_to_collection (metad, AS_FORMAT_KIND_XML, &error);
+		data = as_metadata_components_to_catalog (metad, AS_FORMAT_KIND_XML, &error);
 		g_assert_no_error (error);
 	}
 
@@ -98,13 +98,27 @@ as_xml_test_compare_xml (const gchar *result, const gchar *expected)
 	return as_test_compare_lines (result, expected_full);
 }
 
+/**
+ * test_log_allow_warnings:
+ *
+ * Helper function to temporarily allow warnings to be non-fatal.
+ */
+static gboolean
+test_log_allow_warnings (const gchar *log_domain,
+			     GLogLevelFlags log_level,
+			     const gchar *message,
+			     gpointer user_data)
+{
+	return ((log_level & G_LOG_LEVEL_MASK) <= G_LOG_LEVEL_CRITICAL);
+}
+
 /**
  * test_appstream_parser_legacy:
  *
  * Test parsing legacy metainfo files.
  */
 static void
-test_appstream_parser_legacy ()
+test_appstream_parser_legacy (void)
 {
 	AsMetadata *metad;
 	GFile *file;
@@ -140,7 +154,7 @@ test_appstream_parser_legacy ()
  * Test reading localized tags.
  */
 static void
-test_appstream_parser_locale ()
+test_appstream_parser_locale (void)
 {
 	g_autoptr(AsMetadata) metad = NULL;
 	g_autoptr(GFile) file = NULL;
@@ -204,7 +218,7 @@ test_appstream_parser_locale ()
  * Test writing fully localized entries.
  */
 static void
-test_appstream_write_locale ()
+test_appstream_write_locale (void)
 {
 	AsMetadata *metad;
 	GFile *file;
@@ -278,7 +292,7 @@ test_appstream_write_locale ()
  * Test writing the description tag for catalog and metainfo XML.
  */
 static void
-test_appstream_write_description ()
+test_appstream_write_description (void)
 {
 	guint i;
 	gchar *tmp;
@@ -348,7 +362,7 @@ test_appstream_write_description ()
 						"  </releases>\n"
 						"</component>\n";
 
-	const gchar *EXPECTED_XML_DISTRO = "<components version=\"0.14\">\n"
+	const gchar *EXPECTED_XML_DISTRO = "<components version=\"0.16\">\n"
 					   "  <component>\n"
 					   "    <id>org.example.Test</id>\n"
 					   "    <name>Test</name>\n"
@@ -444,26 +458,26 @@ test_appstream_write_description ()
 	g_assert_true (as_xml_test_compare_xml (tmp, EXPECTED_XML_LOCALIZED));
 	g_free (tmp);
 
-	/* test collection-xml conversion */
-	tmp = as_metadata_components_to_collection (metad, AS_FORMAT_KIND_XML, NULL);
+	/* test catalog XML conversion */
+	tmp = as_metadata_components_to_catalog (metad, AS_FORMAT_KIND_XML, NULL);
 	g_assert_true (as_xml_test_compare_xml (tmp, EXPECTED_XML_DISTRO));
 	g_free (tmp);
 
-	/* test collection XMl -> metainfo XML */
+	/* test catalog XMl -> metainfo XML */
 	as_metadata_clear_components (metad);
-	as_metadata_set_format_style (metad, AS_FORMAT_STYLE_COLLECTION);
+	as_metadata_set_format_style (metad, AS_FORMAT_STYLE_CATALOG);
 	as_metadata_parse (metad, EXPECTED_XML_DISTRO, AS_FORMAT_KIND_XML, &error);
 	g_assert_no_error (error);
 	tmp = as_metadata_component_to_metainfo (metad, AS_FORMAT_KIND_XML, NULL);
 	g_assert_true (as_xml_test_compare_xml (tmp, EXPECTED_XML_LOCALIZED));
 	g_free (tmp);
 
-	/* test metainfo XMl -> collection XML */
+	/* test metainfo XMl -> catalog XML */
 	as_metadata_clear_components (metad);
 	as_metadata_set_format_style (metad, AS_FORMAT_STYLE_METAINFO);
 	as_metadata_parse (metad, EXPECTED_XML_LOCALIZED, AS_FORMAT_KIND_XML, &error);
 	g_assert_no_error (error);
-	tmp = as_metadata_components_to_collection (metad, AS_FORMAT_KIND_XML, NULL);
+	tmp = as_metadata_components_to_catalog (metad, AS_FORMAT_KIND_XML, NULL);
 	g_assert_true (as_xml_test_compare_xml (tmp, EXPECTED_XML_DISTRO));
 	g_free (tmp);
 }
@@ -812,7 +826,7 @@ test_xml_write_suggests (void)
 					   "    <id>org.example.Awesome</id>\n"
 					   "  </suggests>\n"
 					   "</component>\n";
-	const gchar *expected_sug_xml_coll = "<components version=\"0.14\">\n"
+	const gchar *expected_sug_xml_coll = "<components version=\"0.16\">\n"
 					"  <component>\n"
 					"    <id>org.example.SuggestsTest</id>\n"
 					"    <suggests type=\"upstream\">\n"
@@ -844,8 +858,8 @@ test_xml_write_suggests (void)
 	g_assert_true (as_xml_test_compare_xml (res, expected_sug_xml_mi));
 	g_free (res);
 
-	/* test collection serialization */
-	res = as_xml_test_serialize (cpt, AS_FORMAT_STYLE_COLLECTION);
+	/* test catalog serialization */
+	res = as_xml_test_serialize (cpt, AS_FORMAT_STYLE_CATALOG);
 	g_assert_true (as_xml_test_compare_xml (res, expected_sug_xml_coll));
 }
 
@@ -1039,10 +1053,10 @@ test_xml_write_launchable (void)
 }
 
 /**
- * test_appstream_write_metainfo_to_collection:
+ * test_appstream_write_metainfo_to_catalog:
  */
 static void
-test_appstream_write_metainfo_to_collection (void)
+test_appstream_write_metainfo_to_catalog (void)
 {
 	gchar *tmp;
 	g_autoptr(AsMetadata) metad = NULL;
@@ -1094,7 +1108,7 @@ test_appstream_write_metainfo_to_collection (void)
 					"  </releases>\n"
 					"</component>\n";
 
-	const gchar *EXPECTED_XML_COLL =   "<components version=\"0.14\">\n"
+	const gchar *EXPECTED_XML_COLL =   "<components version=\"0.16\">\n"
 					   "  <component>\n"
 					   "    <id>org.example.Test</id>\n"
 					   "    <name>Test</name>\n"
@@ -1154,9 +1168,9 @@ test_appstream_write_metainfo_to_collection (void)
 	as_metadata_parse (metad, METAINFO_XML, AS_FORMAT_KIND_XML, &error);
 	g_assert_no_error (error);
 
-	as_metadata_set_format_style (metad, AS_FORMAT_STYLE_COLLECTION);
+	as_metadata_set_format_style (metad, AS_FORMAT_STYLE_CATALOG);
 
-	tmp = as_metadata_components_to_collection (metad, AS_FORMAT_KIND_XML, NULL);
+	tmp = as_metadata_components_to_catalog (metad, AS_FORMAT_KIND_XML, NULL);
 	g_assert_true (as_xml_test_compare_xml (tmp, EXPECTED_XML_COLL));
 	g_free (tmp);
 }
@@ -1776,6 +1790,7 @@ test_xml_read_releases (void)
 	g_assert_cmpstr (as_component_get_id (cpt), ==, "org.example.ReleaseTest");
 
 	g_assert_cmpint (as_component_get_releases (cpt)->len, ==, 1);
+	g_assert_cmpint (as_component_get_releases_kind (cpt), ==, AS_RELEASES_KIND_EMBEDDED);
 
 	rel = AS_RELEASE (g_ptr_array_index (as_component_get_releases (cpt), 0));
 	g_assert_cmpint (as_release_get_kind (rel), ==, AS_RELEASE_KIND_STABLE);
@@ -2085,6 +2100,65 @@ test_xml_rw_branding (void)
 	g_assert_true (as_xml_test_compare_xml (res, xmldata_tags));
 }
 
+/**
+ * test_xml_rw_external_releases:
+ */
+static void
+test_xml_rw_external_releases (void)
+{
+	static const gchar *xmldata_tags =
+			"<component>\n"
+			"  <id>org.example.ExternalReleaseTest</id>\n"
+			"  <releases type=\"external\" url=\"https://example.com/releases/test.releases.xml\"/>\n"
+			"</component>\n";
+	g_autoptr(AsComponent) cpt = NULL;
+	g_autoptr(AsMetadata) metad = NULL;
+	g_autoptr(GFile) file = NULL;
+	g_autofree gchar *path = NULL;
+	g_autofree gchar *res = NULL;
+	GPtrArray *releases;
+	g_autoptr(GError) error = NULL;
+
+	/* read */
+	cpt = as_xml_test_read_data (xmldata_tags, AS_FORMAT_STYLE_METAINFO);
+	g_assert_cmpstr (as_component_get_id (cpt), ==, "org.example.ExternalReleaseTest");
+
+	/* validate */
+
+	/* we ignore warnings, as this will throw one since we can not find the external release info file */
+	g_test_log_set_fatal_handler (test_log_allow_warnings, NULL);
+	releases = as_component_get_releases (cpt);
+	g_test_log_set_fatal_handler (NULL, NULL);
+
+	g_assert_nonnull (releases);
+	g_assert_cmpint (releases->len, ==, 0);
+
+	g_assert_cmpstr (as_component_get_releases_url (cpt), ==, "https://example.com/releases/test.releases.xml");
+	g_assert_cmpint (as_component_get_releases_kind (cpt), ==, AS_RELEASES_KIND_EXTERNAL);
+
+	/* write */
+	res = as_xml_test_serialize (cpt, AS_FORMAT_STYLE_METAINFO);
+	g_assert_true (as_xml_test_compare_xml (res, xmldata_tags));
+
+	/* test reading from file */
+	metad = as_metadata_new ();
+
+	path = g_build_filename (datadir, "org.example.pomidaq.metainfo.xml", NULL);
+	file = g_file_new_for_path (path);
+
+	as_metadata_parse_file (metad, file, AS_FORMAT_KIND_XML, &error);
+	g_assert_no_error (error);
+	g_object_unref (g_steal_pointer (&cpt));
+	cpt = g_object_ref (as_metadata_get_component (metad));
+
+	g_assert_cmpstr (as_component_get_id (cpt), ==, "org.example.pomidaq");
+	releases = as_component_get_releases (cpt);
+	g_assert_nonnull (releases);
+	g_assert_cmpint (releases->len, ==, 4);
+	g_assert_cmpstr (as_component_get_releases_url (cpt), ==, "https://raw.githubusercontent.com/ximion/appstream/master/tests/samples/releases/org.example.pomidaq.releases.xml");
+	g_assert_cmpint (as_component_get_releases_kind (cpt), ==, AS_RELEASES_KIND_EXTERNAL);
+}
+
 /**
  * main:
  */
@@ -2117,7 +2191,7 @@ main (int argc, char **argv)
 	g_test_add_func ("/XML/Write/Description", test_appstream_write_description);
 	g_test_add_func ("/XML/DescriptionL10NCleanup", test_appstream_description_l10n_cleanup);
 
-	g_test_add_func ("/XML/Write/MetainfoToCollection", test_appstream_write_metainfo_to_collection);
+	g_test_add_func ("/XML/Write/MetainfoToCatalog", test_appstream_write_metainfo_to_catalog);
 
 	g_test_add_func ("/XML/Read/Simple", test_xml_read_simple);
 	g_test_add_func ("/XML/Write/Simple", test_xml_write_simple);
@@ -2156,6 +2230,7 @@ main (int argc, char **argv)
 	g_test_add_func ("/XML/ReadWrite/Reviews", test_xml_rw_reviews);
 	g_test_add_func ("/XML/ReadWrite/Tags", test_xml_rw_tags);
 	g_test_add_func ("/XML/ReadWrite/Branding", test_xml_rw_branding);
+	g_test_add_func ("/XML/ReadWrite/ExternalReleases", test_xml_rw_external_releases);
 
 	ret = g_test_run ();
 	g_free (datadir);
