@@ -44,7 +44,7 @@ as_yaml_test_serialize (AsComponent *cpt)
 	as_metadata_add_component (metad, cpt);
 	as_metadata_set_write_header (metad, TRUE);
 
-	data = as_metadata_components_to_collection (metad, AS_FORMAT_KIND_YAML, &error);
+	data = as_metadata_components_to_catalog (metad, AS_FORMAT_KIND_YAML, &error);
 	g_assert_no_error (error);
 
 	return data;
@@ -64,12 +64,12 @@ as_yaml_test_read_data (const gchar *data, GError **error)
 
 	data_full = g_strdup_printf ("---\n"
 				     "File: DEP-11\n"
-				     "Version: '0.14'\n"
+				     "Version: '0.16'\n"
 				     "---\n%s", data);
 
 	metad = as_metadata_new ();
 	as_metadata_set_locale (metad, "ALL");
-	as_metadata_set_format_style (metad, AS_FORMAT_STYLE_COLLECTION);
+	as_metadata_set_format_style (metad, AS_FORMAT_STYLE_CATALOG);
 
 	if (error == NULL) {
 		g_autoptr(GError) local_error = NULL;
@@ -104,7 +104,7 @@ as_yaml_test_compare_yaml (const gchar *result, const gchar *expected)
 	g_autofree gchar *expected_full = NULL;
 	expected_full = g_strdup_printf ("---\n"
 					 "File: DEP-11\n"
-					 "Version: '0.14'\n"
+					 "Version: '0.16'\n"
 					 "---\n%s", expected);
 	return as_test_compare_lines (result, expected_full);
 }
@@ -127,7 +127,7 @@ test_yaml_basic (void)
 
 	mdata = as_metadata_new ();
 	as_metadata_set_locale (mdata, "C");
-	as_metadata_set_format_style (mdata, AS_FORMAT_STYLE_COLLECTION);
+	as_metadata_set_format_style (mdata, AS_FORMAT_STYLE_CATALOG);
 
 	path = g_build_filename (datadir, "dep11-0.8.yml", NULL);
 	file = g_file_new_for_path (path);
@@ -398,7 +398,7 @@ test_yamlwrite_misc (void)
 	g_object_unref (cpt);
 
 	/* serialize and validate */
-	resdata = as_metadata_components_to_collection (metad, AS_FORMAT_KIND_YAML, &error);
+	resdata = as_metadata_components_to_catalog (metad, AS_FORMAT_KIND_YAML, &error);
 	g_assert_no_error (error);
 
 	g_assert_true (as_yaml_test_compare_yaml (resdata, expected_yaml));
@@ -593,7 +593,7 @@ test_yaml_write_simple (void)
 	as_component_set_summary (cpt, "Just part of an unittest", "C");
 	as_component_set_name_variant_suffix (cpt, "Generic", "C");
 
-	/* test collection serialization */
+	/* test catalog serialization */
 	res = as_yaml_test_serialize (cpt);
 	g_assert_true (as_yaml_test_compare_yaml (res, yamldata_simple_fields));
 }
@@ -684,7 +684,7 @@ test_yaml_write_provides (void)
 	as_provided_add_item (prov_firmware_flashed, "84f40464-9272-4ef7-9399-cd95f12da696");
 	as_component_add_provided (cpt, prov_firmware_flashed);
 
-	/* test collection serialization */
+	/* test catalog serialization */
 	res = as_yaml_test_serialize (cpt);
 	g_assert_true (as_yaml_test_compare_yaml (res, expected_prov_yaml));
 }
@@ -798,7 +798,7 @@ test_yaml_write_suggests (void)
 	as_suggested_add_id (sug_hr, "org.example.Stuff");
 	as_component_add_suggested (cpt, sug_hr);
 
-	/* test collection serialization */
+	/* test catalog serialization */
 	res = as_yaml_test_serialize (cpt);
 	g_assert_true (as_yaml_test_compare_yaml (res, expected_sug_yaml));
 }
@@ -874,7 +874,7 @@ test_yaml_write_custom (void)
 	as_component_insert_custom_value (cpt, "foo bar", "value-with space");
 	as_component_insert_custom_value (cpt, "Oh::Snap::Punctuation!", "Awesome!");
 
-	/* test collection serialization */
+	/* test catalog serialization */
 	res = as_yaml_test_serialize (cpt);
 	g_assert_true (as_yaml_test_compare_yaml (res, yamldata_custom_field));
 }
@@ -929,7 +929,7 @@ test_yaml_write_content_rating (void)
 
 	as_component_add_content_rating (cpt, rating);
 
-	/* test collection serialization */
+	/* test catalog serialization */
 	res = as_yaml_test_serialize (cpt);
 	g_assert_true (as_yaml_test_compare_yaml (res, yamldata_content_rating_field));
 }
@@ -987,7 +987,7 @@ test_yaml_write_launchable (void)
 
 	as_component_add_launchable (cpt, launch);
 
-	/* test collection serialization */
+	/* test catalog serialization */
 	res = as_yaml_test_serialize (cpt);
 	g_assert_true (as_yaml_test_compare_yaml (res, yamldata_launchable_field));
 }
@@ -1017,20 +1017,26 @@ test_yaml_read_launchable (void)
 static const gchar *yamldata_relations_field =
 				"Type: generic\n"
 				"ID: org.example.RelationsTest\n"
+				"Replaces:\n"
+				"- id: org.example.old_test\n"
 				"Requires:\n"
 				"- kernel: Linux\n"
 				"  version: '>= 4.15'\n"
 				"- id: org.example.TestDependency\n"
 				"  version: == 1.2\n"
 				"- display_length: 4200\n"
+				"- internet: always\n"
+				"  bandwidth_mbitps: 2\n"
 				"Recommends:\n"
 				"- memory: 2500\n"
 				"- modalias: usb:v1130p0202d*\n"
 				"- display_length: <= xlarge\n"
 				"  side: longest\n"
+				"- internet: first-run\n"
 				"Supports:\n"
 				"- control: gamepad\n"
-				"- control: keyboard\n";
+				"- control: keyboard\n"
+				"- internet: offline-only\n";
 
 /**
  * test_yaml_write_relations:
@@ -1050,6 +1056,9 @@ test_yaml_write_relations (void)
 	g_autoptr(AsRelation) dl_relation2 = NULL;
 	g_autoptr(AsRelation) ctl_relation1 = NULL;
 	g_autoptr(AsRelation) ctl_relation2 = NULL;
+	g_autoptr(AsRelation) internet_relation1 = NULL;
+	g_autoptr(AsRelation) internet_relation2 = NULL;
+	g_autoptr(AsRelation) internet_relation3 = NULL;
 
 	cpt = as_component_new ();
 	as_component_set_kind (cpt, AS_COMPONENT_KIND_GENERIC);
@@ -1063,6 +1072,9 @@ test_yaml_write_relations (void)
 	dl_relation2 = as_relation_new ();
 	ctl_relation1 = as_relation_new ();
 	ctl_relation2 = as_relation_new ();
+	internet_relation1 = as_relation_new ();
+	internet_relation2 = as_relation_new ();
+	internet_relation3 = as_relation_new ();
 
 	as_relation_set_kind (mem_relation, AS_RELATION_KIND_RECOMMENDS);
 	as_relation_set_kind (moda_relation, AS_RELATION_KIND_RECOMMENDS);
@@ -1072,6 +1084,9 @@ test_yaml_write_relations (void)
 	as_relation_set_kind (dl_relation2, AS_RELATION_KIND_REQUIRES);
 	as_relation_set_kind (ctl_relation1, AS_RELATION_KIND_SUPPORTS);
 	as_relation_set_kind (ctl_relation2, AS_RELATION_KIND_SUPPORTS);
+	as_relation_set_kind (internet_relation1, AS_RELATION_KIND_REQUIRES);
+	as_relation_set_kind (internet_relation2, AS_RELATION_KIND_RECOMMENDS);
+	as_relation_set_kind (internet_relation3, AS_RELATION_KIND_SUPPORTS);
 
 	as_relation_set_item_kind (mem_relation, AS_RELATION_ITEM_KIND_MEMORY);
 	as_relation_set_value_int (mem_relation, 2500);
@@ -1097,6 +1112,16 @@ test_yaml_write_relations (void)
 	as_relation_set_value_int (dl_relation2, 4200);
 	as_relation_set_compare (dl_relation2, AS_RELATION_COMPARE_GE);
 
+	as_relation_set_item_kind (internet_relation1, AS_RELATION_ITEM_KIND_INTERNET);
+	as_relation_set_value_internet_kind (internet_relation1, AS_INTERNET_KIND_ALWAYS);
+	as_relation_set_value_internet_bandwidth (internet_relation1, 2);
+
+	as_relation_set_item_kind (internet_relation2, AS_RELATION_ITEM_KIND_INTERNET);
+	as_relation_set_value_internet_kind (internet_relation2, AS_INTERNET_KIND_FIRST_RUN);
+
+	as_relation_set_item_kind (internet_relation3, AS_RELATION_ITEM_KIND_INTERNET);
+	as_relation_set_value_internet_kind (internet_relation3, AS_INTERNET_KIND_OFFLINE_ONLY);
+
 	as_relation_set_item_kind (ctl_relation1, AS_RELATION_ITEM_KIND_CONTROL);
 	as_relation_set_item_kind (ctl_relation2, AS_RELATION_ITEM_KIND_CONTROL);
 	as_relation_set_value_control_kind (ctl_relation1, AS_CONTROL_KIND_GAMEPAD);
@@ -1110,8 +1135,13 @@ test_yaml_write_relations (void)
 	as_component_add_relation (cpt, dl_relation2);
 	as_component_add_relation (cpt, ctl_relation1);
 	as_component_add_relation (cpt, ctl_relation2);
+	as_component_add_relation (cpt, internet_relation1);
+	as_component_add_relation (cpt, internet_relation2);
+	as_component_add_relation (cpt, internet_relation3);
 
-	/* test collection serialization */
+	as_component_add_replaces (cpt, "org.example.old_test");
+
+	/* test catalog serialization */
 	res = as_yaml_test_serialize (cpt);
 	g_assert_true (as_yaml_test_compare_yaml (res, yamldata_relations_field));
 }
@@ -1137,9 +1167,13 @@ test_yaml_read_relations (void)
 	recommends = as_component_get_recommends (cpt);
 	supports = as_component_get_supports (cpt);
 
-	g_assert_cmpint (requires->len, ==, 3);
-	g_assert_cmpint (recommends->len, ==, 3);
-	g_assert_cmpint (supports->len, ==, 2);
+	g_assert_cmpint (requires->len, ==, 4);
+	g_assert_cmpint (recommends->len, ==, 4);
+	g_assert_cmpint (supports->len, ==, 3);
+
+	/* component replacement */
+	g_assert_cmpint (as_component_get_replaces (cpt)->len, ==, 1);
+	g_assert_cmpstr (g_ptr_array_index (as_component_get_replaces (cpt), 0), ==, "org.example.old_test");
 
 	/* memory relation */
 	relation = AS_RELATION (g_ptr_array_index (recommends, 0));
@@ -1160,6 +1194,13 @@ test_yaml_read_relations (void)
 	g_assert_cmpint (as_relation_get_value_display_length_kind (relation), ==, AS_DISPLAY_LENGTH_KIND_XLARGE);
 	g_assert_cmpint (as_relation_get_compare (relation), ==, AS_RELATION_COMPARE_LE);
 
+	/* internet relation (REC) */
+	relation = AS_RELATION (g_ptr_array_index (recommends, 3));
+	g_assert_cmpint (as_relation_get_kind (relation), ==, AS_RELATION_KIND_RECOMMENDS);
+	g_assert_cmpint (as_relation_get_item_kind (relation), ==, AS_RELATION_ITEM_KIND_INTERNET);
+	g_assert_cmpint (as_relation_get_value_internet_kind (relation), ==, AS_INTERNET_KIND_FIRST_RUN);
+	g_assert_cmpint (as_relation_get_value_internet_bandwidth (relation), ==, 0);
+
 	/* kernel relation */
 	relation = AS_RELATION (g_ptr_array_index (requires, 0));
 	g_assert_cmpint (as_relation_get_kind (relation), ==, AS_RELATION_KIND_REQUIRES);
@@ -1183,6 +1224,13 @@ test_yaml_read_relations (void)
 	g_assert_cmpint (as_relation_get_value_px (relation), ==, 4200);
 	g_assert_cmpint (as_relation_get_compare (relation), ==, AS_RELATION_COMPARE_GE);
 
+	/* internet relation (REQ) */
+	relation = AS_RELATION (g_ptr_array_index (requires, 3));
+	g_assert_cmpint (as_relation_get_kind (relation), ==, AS_RELATION_KIND_REQUIRES);
+	g_assert_cmpint (as_relation_get_item_kind (relation), ==, AS_RELATION_ITEM_KIND_INTERNET);
+	g_assert_cmpint (as_relation_get_value_internet_kind (relation), ==, AS_INTERNET_KIND_ALWAYS);
+	g_assert_cmpint (as_relation_get_value_internet_bandwidth (relation), ==, 2);
+
 	/* control relation */
 	relation = AS_RELATION (g_ptr_array_index (supports, 0));
 	g_assert_cmpint (as_relation_get_kind (relation), ==, AS_RELATION_KIND_SUPPORTS);
@@ -1192,6 +1240,13 @@ test_yaml_read_relations (void)
 	g_assert_cmpint (as_relation_get_kind (relation), ==, AS_RELATION_KIND_SUPPORTS);
 	g_assert_cmpint (as_relation_get_item_kind (relation), ==, AS_RELATION_ITEM_KIND_CONTROL);
 	g_assert_cmpint (as_relation_get_value_control_kind (relation), ==, AS_CONTROL_KIND_KEYBOARD);
+
+	/* internet relation (supports) */
+	relation = AS_RELATION (g_ptr_array_index (supports, 2));
+	g_assert_cmpint (as_relation_get_kind (relation), ==, AS_RELATION_KIND_SUPPORTS);
+	g_assert_cmpint (as_relation_get_item_kind (relation), ==, AS_RELATION_ITEM_KIND_INTERNET);
+	g_assert_cmpint (as_relation_get_value_internet_kind (relation), ==, AS_INTERNET_KIND_OFFLINE_ONLY);
+	g_assert_cmpint (as_relation_get_value_internet_bandwidth (relation), ==, 0);
 }
 
 
@@ -1243,7 +1298,7 @@ test_yaml_write_agreements (void)
 	as_agreement_add_section (agreement, sect);
 	as_component_add_agreement (cpt, agreement);
 
-	/* test collection serialization */
+	/* test catalog serialization */
 	res = as_yaml_test_serialize (cpt);
 	g_assert_true (as_yaml_test_compare_yaml (res, yamldata_agreements));
 }
@@ -1374,7 +1429,7 @@ test_yaml_write_screenshots (void)
 	as_component_add_screenshot (cpt, scr1);
 	as_component_add_screenshot (cpt, scr2);
 
-	/* test collection serialization */
+	/* test catalog serialization */
 	res = as_yaml_test_serialize (cpt);
 	g_assert_true (as_yaml_test_compare_yaml (res, yamldata_screenshots));
 }
@@ -1585,7 +1640,7 @@ test_yaml_write_releases (void)
 	as_artifact_set_platform (af2, "x86_64-linux-gnu");
 	as_release_add_artifact (rel2, af2);
 
-	/* test collection serialization */
+	/* test catalog serialization */
 	res = as_yaml_test_serialize (cpt);
 	g_assert_true (as_yaml_test_compare_yaml (res, yamldata_releases_field));
 }
