@@ -41,6 +41,11 @@ int		ascli_get_component (const gchar *cachepath,
 					gboolean detailed,
 					gboolean no_cache);
 
+int		ascli_list_categories (const gchar *cachepath,
+					gchar **categories,
+					gboolean detailed,
+					gboolean no_cache);
+
 int		ascli_refresh_cache (const gchar *cachepath,
 					const gchar *datapath,
 					const gchar * const* sources_str,
@@ -59,13 +64,14 @@ int		ascli_convert_data (const gchar *in_fname,
 				    const gchar *out_fname,
 				    AsFormatKind mformat);
 
-int		ascli_show_os_info (const gchar *cachepath,
-				    gboolean no_cache);
-
 int		ascli_create_metainfo_template (const gchar *out_fname,
 						const gchar *cpt_kind_str,
 						const gchar *desktop_file);
 
+gint		ascli_check_is_satisfied (const gchar *fname_or_cid,
+					  const gchar *cachepath,
+					  gboolean no_cache);
+
 
 G_END_DECLS
 
