@@ -25,6 +25,8 @@
 #include <unistd.h>
 #include <glib/gi18n-lib.h>
 
+#include "as-pool-private.h"
+
 /**
  * Set to true if we don't want colored output
  */
@@ -100,8 +102,15 @@ ascli_print_key_value (const gchar* key, const gchar* val, gboolean line_wrap)
  * ascli_print_highlight:
  */
 void
-ascli_print_highlight (const gchar* msg)
+ascli_print_highlight (const gchar *format, ...)
 {
+	va_list args;
+	g_autofree gchar *msg = NULL;
+
+	va_start (args, format);
+	msg = g_strdup_vprintf (format, args);
+	va_end (args);
+
 	if (_colored_output) {
 		g_print ("%c[%dm%s%c[%dm\n", 0x1B, 1, msg, 0x1B, 0);
 	} else {
@@ -113,7 +122,7 @@ ascli_print_highlight (const gchar* msg)
  * ascli_print_separator:
  */
 void
-ascli_print_separator ()
+ascli_print_separator (void)
 {
 	if (_colored_output) {
 		g_print ("%c[%dm%s\n%c[%dm", 0x1B, 36, "---", 0x1B, 0);
@@ -129,15 +138,13 @@ void
 ascli_print_stderr (const gchar *format, ...)
 {
 	va_list args;
-	gchar *str;
+	g_autofree gchar *str = NULL;
 
 	va_start (args, format);
 	str = g_strdup_vprintf (format, args);
 	va_end (args);
 
 	g_printerr ("%s\n", str);
-
-	g_free (str);
 }
 
 /**
@@ -158,6 +165,31 @@ ascli_print_stdout (const gchar *format, ...)
 	g_free (str);
 }
 
+/**
+ * ascli_get_char_success:
+ */
+const gchar*
+ascli_get_char_success (void)
+{
+	if (_colored_output)
+		return "\x1B[32m" "✔" "\033[0m";
+	else
+		return "✔";
+}
+
+/**
+ * ascli_get_char_failure:
+ */
+const gchar*
+ascli_get_char_failure (void)
+{
+	if (_colored_output)
+		return "\x1B[31m" "✘" "\033[0m";
+	else
+		return "✘";
+}
+
+
 /**
  * ascli_set_output_colored:
  */
@@ -171,7 +203,7 @@ ascli_set_output_colored (gboolean colored)
  * ascli_get_output_colored:
  */
 gboolean
-ascli_get_output_colored ()
+ascli_get_output_colored (void)
 {
 	return _colored_output;
 }
@@ -375,8 +407,10 @@ ascli_print_component (AsComponent *cpt, gboolean show_detailed)
 
 		/* Provided Items */
 		provided = as_component_get_provided (cpt);
-		if (provided->len > 0)
+		if (provided->len > 0) {
+			/* TRANSLATORS: Other software or interfaces that this software component provides */
 			ascli_print_key_value (_("Provided Items"), "↓", FALSE);
+		}
 		for (i = 0; i < provided->len; i++) {
 			GPtrArray *items = NULL;
 			AsProvided *prov = AS_PROVIDED (g_ptr_array_index (provided, i));
@@ -413,6 +447,33 @@ ascli_print_components (GPtrArray *cpts, gboolean show_detailed)
 	}
 }
 
+/**
+ * ascli_data_pool_new_and_open:
+ */
+AsPool*
+ascli_data_pool_new_and_open (const gchar *cachepath, gboolean no_cache, GError **error)
+{
+	AsPool *dpool;
+	AsPoolFlags flags;
+
+	dpool = as_pool_new ();
+	flags = as_pool_get_flags (dpool);
+	if (no_cache)
+		as_flags_add (flags, AS_POOL_FLAG_IGNORE_CACHE_AGE);
+
+	if (cachepath == NULL) {
+		/* no cache object to load, we can use a normal pool */
+		as_pool_load (dpool, NULL, error);
+	} else {
+		/* use an exported cache object */
+		as_pool_override_cache_locations (dpool, cachepath, cachepath);
+		as_pool_load (dpool, NULL, error);
+	}
+	as_pool_set_flags (dpool, flags);
+
+	return dpool;
+}
+
 /**
  * ascli_query_numer:
  * @question: question to ask user
